"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addConnection = void 0;
const uuid_1 = require("uuid");
const args_1 = require("./args");
exports.addConnection = (args, db) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    // Validate args
    const required = [args_1.Arg.name, args_1.Arg.appId, args_1.Arg.url, args_1.Arg.masterKey];
    required.forEach((arg) => {
        if (!args.has(arg) ||
            args.get(arg) === undefined ||
            args.get(arg) === null ||
            args.get(arg).toString().length < 1) {
            throw new Error(`${arg} is required for --addConnection!`);
        }
    });
    const [appId, serverName, serverUrl, jsKey, masterKey] = [
        args.get(args_1.Arg.appId).toString(),
        args.get(args_1.Arg.name).toString(),
        args.get(args_1.Arg.url).toString(),
        (_a = args.get(args_1.Arg.jsKey)) === null || _a === void 0 ? void 0 : _a.toString(),
        args.get(args_1.Arg.masterKey).toString(),
    ];
    const parseConfig = {
        id: uuid_1.v4(),
        active: true,
        appId,
        serverName,
        serverUrl,
        jsKey,
        masterKey,
    };
    const config = yield db.parseconfigs.upsert(parseConfig);
    const connected = config.connect();
    console.log('\x1b[32m%s\x1b[0m', `Connection ${serverName} added and set as active connection, ${connected
        ? 'connected to leap-one server!'
        : `but couldn't connect to leap-one server at ${serverUrl}`}`);
    return config;
});
//# sourceMappingURL=addConnection.js.map