"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValuesFromArgs = exports.ArgValType = exports.Arg = void 0;
var Arg;
(function (Arg) {
    Arg["addConnection"] = "--addConnection";
    Arg["name"] = "--name";
    Arg["url"] = "--url";
    Arg["appId"] = "--appId";
    Arg["masterKey"] = "--masterKey";
    Arg["jsKey"] = "--jsKey";
    Arg["useConnection"] = "--useConnection";
    Arg["createRandCompany"] = "--createRandCompany";
    Arg["noContracts"] = "--noContracts";
    Arg["noCreditApps"] = "--noCreditApps";
    Arg["noEstimates"] = "--noEstimates";
    Arg["noMeasureItems"] = "--noMeasureItems";
    Arg["noOffices"] = "--noOffices";
    Arg["noUsers"] = "--noUsers";
    Arg["partnerTag"] = "--partnerTag";
})(Arg = exports.Arg || (exports.Arg = {}));
// TypeGuard for Arg
const isArg = (arg) => Object.values(Arg).includes(arg);
exports.ArgValType = new Map([
    [Arg.addConnection, null],
    [Arg.name, 'string'],
    [Arg.url, 'string'],
    [Arg.appId, 'string'],
    [Arg.masterKey, 'string'],
    [Arg.jsKey, 'string'],
    [Arg.useConnection, null],
    [Arg.createRandCompany, null],
    [Arg.noContracts, 'integer'],
    [Arg.noCreditApps, 'integer'],
    [Arg.noEstimates, 'integer'],
    [Arg.noMeasureItems, 'integer'],
    [Arg.noOffices, 'integer'],
    [Arg.noUsers, 'integer'],
    [Arg.partnerTag, 'string'],
]);
exports.getValuesFromArgs = (userArgs) => {
    const args = [...userArgs]; // clone args so we don't modify orignal
    // Create a value map from args
    const values = new Map();
    for (let i = 0; i < args.length; i++) {
        const arg = args[i];
        if (isArg(arg)) {
            const t = exports.ArgValType.get(arg);
            switch (t) {
                case null:
                    values.set(arg, null);
                    break;
                case 'integer': {
                    const value = Number(args[i + 1]); // element after arg is the val
                    if (value < 0 || isNaN(value) || !Number.isInteger(value)) {
                        throw new Error(`Expected a positive integer for "${arg}" but received ${args[i + 1]}`);
                    }
                    values.set(arg, value);
                    i++; // skip next element since it's a value and not arg
                    break;
                }
                case 'string': {
                    const value = args[i + 1]; // element after arg is the val
                    values.set(arg, value);
                    i++; // skip next element since it's a value and not arg
                    break;
                }
            }
        }
        else {
            throw new Error(`${arg} is not a valid argument!`);
        }
    }
    return values;
};
//# sourceMappingURL=args.js.map