'use strict';
var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    function adopt(value) {
        return value instanceof P ? value : new P(function (resolve) {
            resolve(value);
        });
    }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator['throw'](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = this && this.__importDefault || function (mod) {
    return mod && mod.__esModule ? mod : { 'default': mod };
};
Object.defineProperty(exports, '__esModule', { value: true });
exports.createRandomCompany = void 0;
const args_1 = require('./args');
const generateRandCompany_1 = __importDefault(require('../util/generateRandCompany'));
const types_1 = require('./types');
exports.createRandomCompany = (args, db) => __awaiter(void 0, void 0, void 0, function* () {
    // Validate args
    const required = [
        args_1.Arg.noContracts,
        args_1.Arg.noCreditApps,
        args_1.Arg.noEstimates,
        args_1.Arg.noMeasureItems,
        args_1.Arg.noOffices,
        args_1.Arg.noUsers
    ];
    required.forEach(arg => {
        if (!args.has(arg)) {
            console.error(new Error(`${ arg } is required for --createRandCompany!`));
        }
    });
    const [noContracts, noCreditApps, noEstimates, noMeasureItems, noOffices, noUsers, partnerTag] = [
        Number(args.get(args_1.Arg.noContracts)),
        Number(args.get(args_1.Arg.noCreditApps)),
        Number(args.get(args_1.Arg.noEstimates)),
        Number(args.get(args_1.Arg.noMeasureItems)),
        Number(args.get(args_1.Arg.noOffices)),
        Number(args.get(args_1.Arg.noUsers)),
        args.get(args_1.Arg.partnerTag) === 'Prosell' ? 'Prosell' : 'Leap'
    ];
    const activeQuery = db.parseconfigs.findOne({ selector: { active: { $eq: true } } });
    const activeConfig = yield activeQuery.exec();
    if (activeConfig) {
        const connected = yield activeConfig.connect();
        if (!connected) {
            throw new Error(`Could not connect to ${ activeConfig.serverUrl }`);
        }
    } else {
        throw new Error('No active parse config!');
    }
    const companyDoc = yield db.companyseeds.getRandom();
    const consoleLog = (msg, color) => {
        let consoleColor;
        const colorEnd = types_1.ConsoleColor.Content + types_1.ConsoleColor.Reset;
        switch (color) {
        case 'normal':
            consoleColor = types_1.ConsoleColor.FgWhite + colorEnd;
            break;
        case 'danger':
            consoleColor = types_1.ConsoleColor.FgRed + colorEnd;
            break;
        case 'success':
            consoleColor = types_1.ConsoleColor.FgGreen + colorEnd;
            break;
        case 'warning':
            consoleColor = types_1.ConsoleColor.FgYellow + colorEnd;
            break;
        default:
            consoleColor = types_1.ConsoleColor.Reset;
        }
        console.log(consoleColor, msg);
    };
    try {
        yield generateRandCompany_1.default(companyDoc, consoleLog, db, noContracts, noCreditApps, noEstimates, noMeasureItems, noOffices, noUsers, partnerTag);
    } catch (e) {
        console.error(e);
    }
});    //# sourceMappingURL=createRandomCompany.js.map
