"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useConnection = void 0;
const args_1 = require("./args");
exports.useConnection = (args, db) => __awaiter(void 0, void 0, void 0, function* () {
    // Validate args
    const required = [args_1.Arg.name];
    required.forEach((arg) => {
        if (!args.has(arg)) {
            console.error(new Error(`${arg} is required for --useConnection!`));
        }
    });
    // connect to DB from render process
    const name = args.get(args_1.Arg.name);
    const parseConfig = yield db.parseconfigs
        .findOne()
        .where('serverName')
        .equals(name)
        .exec();
    if (parseConfig === null) {
        console.error(new Error(`No connection config exists with a name of ${name}`));
    }
    else {
        const connected = yield parseConfig.connect();
        const { serverName, serverUrl } = parseConfig;
        console.log('\x1b[32m%s\x1b[0m', `Connection ${serverName} added and set as active connection, ${connected
            ? 'connected to leap-one server!'
            : `but couldn't connect to leap-one server at ${serverUrl}`}`);
    }
});
//# sourceMappingURL=useConnection.js.map