"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeDatabase = void 0;
/* eslint-disable max-lines */
const graceful_fs_1 = __importDefault(require("graceful-fs"));
const path_1 = __importDefault(require("path"));
const os_1 = __importDefault(require("os"));
const mkdirp_1 = __importDefault(require("mkdirp"));
const rxjs_1 = require("rxjs");
const rxdb_1 = require("rxdb");
const collections_1 = require("./types/collections");
const parseConfigSchema_1 = require("./schemas/parseConfigSchema");
const companySeedSchema_1 = require("./schemas/companySeedSchema");
const officeSeedSchema_1 = require("./schemas/officeSeedSchema");
const userSeedSchema_1 = require("./schemas/userSeedSchema");
const priceGuideSeedSchema_1 = require("./schemas/priceGuideSeedSchema");
const estimateSeedSchema_1 = require("./schemas/estimateSeedSchema");
const contactSeedSchema_1 = require("./schemas/contactSeedSchema");
const addressSeedSchema_1 = require("./schemas/addressSeedSchema");
const customerSchema_1 = require("./schemas/customerSchema");
const creditApplicationSchema_1 = require("./schemas/creditApplicationSchema");
const contractSeedSchema_1 = require("./schemas/contractSeedSchema");
const seedFileSchema_1 = __importDefault(require("./schemas/seedFileSchema"));
const seedAddressData_1 = __importDefault(require("./seedData/seedAddressData"));
const seedCompanyData_1 = __importDefault(require("./seedData/seedCompanyData"));
const seedContactData_1 = __importDefault(require("./seedData/seedContactData"));
const seedContractData_1 = __importDefault(require("./seedData/seedContractData"));
const seedCreditApplicationData_1 = __importDefault(require("./seedData/seedCreditApplicationData"));
const seedCustomerData_1 = __importDefault(require("./seedData/seedCustomerData"));
const seedEstimateData_1 = __importDefault(require("./seedData/seedEstimateData"));
const seedOfficeData_1 = __importDefault(require("./seedData/seedOfficeData"));
const seedFiles_1 = __importDefault(require("./seedData/seedFiles"));
const seedPriceGuideData_1 = __importDefault(require("./seedData/seedPriceGuideData"));
const seedUserData_1 = __importDefault(require("./seedData/seedUserData"));
const dbDir = process.env.NODE_ENV === 'production'
    ? path_1.default.resolve(os_1.default.homedir(), '.leap-data-generator', 'rxdb')
    : path_1.default.resolve(process.cwd(), 'rxdb');
// If the dir for the db doesn't exist in the user's home,
// create it
if (!graceful_fs_1.default.existsSync(dbDir)) {
    mkdirp_1.default.sync(dbDir);
}
// eslint-disable-next-line max-len
exports.initializeDatabase = (adapter, seedJSONPath) => new rxjs_1.Observable((subscriber) => {
    const createDB = () => __awaiter(void 0, void 0, void 0, function* () {
        subscriber.next({
            message: 'Opening Leap Seed Database',
            progress: 0,
        });
        // Create db collections
        const db = yield rxdb_1.createRxDatabase({
            name: `${dbDir}/leapgendb`,
            adapter,
        });
        // actions to load and seed the db
        const steps = [
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.ParseConfigs,
                    schema: parseConfigSchema_1.parseConfigSchema,
                    methods: parseConfigSchema_1.parseConfigMethods,
                    statics: parseConfigSchema_1.parseConfigCollectionMethods,
                }),
                message: 'Creating Parse Configurations Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.CompanySeeds,
                    schema: companySeedSchema_1.companySeedSchema,
                    methods: companySeedSchema_1.companySeedMethods,
                    statics: companySeedSchema_1.companySeedCollectionMethods,
                }),
                message: 'Creating Copmany Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.OfficeSeeds,
                    schema: officeSeedSchema_1.officeSeedSchema,
                    methods: officeSeedSchema_1.officeSeedMethods,
                    statics: officeSeedSchema_1.officeSeedCollectionMethods,
                }),
                message: 'Creating Office Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.UserSeeds,
                    schema: userSeedSchema_1.userSeedSchema,
                    methods: userSeedSchema_1.userSeedMethods,
                    statics: userSeedSchema_1.userSeedCollectionMethods,
                }),
                message: 'Creating User Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.PriceGuideSeeds,
                    schema: priceGuideSeedSchema_1.priceGuideSeedSchema,
                    methods: priceGuideSeedSchema_1.priceGuideSeedMethods,
                    statics: priceGuideSeedSchema_1.priceGuideSeedCollectionMethods,
                }),
                message: 'Creating Price Guide Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.EstimateSeeds,
                    schema: estimateSeedSchema_1.estimateSeedSchema,
                    methods: estimateSeedSchema_1.estimateSeedMethods,
                    statics: estimateSeedSchema_1.estimateSeedCollectionMethods,
                }),
                message: 'Creating Estimate Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.ContactSeeds,
                    schema: contactSeedSchema_1.contactSeedSchema,
                    methods: contactSeedSchema_1.contactSeedMethods,
                    statics: contactSeedSchema_1.contactSeedCollectionMethods,
                }),
                message: 'Creating Contact Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.AddressSeeds,
                    schema: addressSeedSchema_1.addressSeedSchema,
                    methods: addressSeedSchema_1.addressSeedMethods,
                    statics: addressSeedSchema_1.addressSeedCollectionMethods,
                }),
                message: 'Creating Address Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.CustomerSeeds,
                    schema: customerSchema_1.customerSeedSchema,
                    methods: customerSchema_1.customerSeedMethods,
                    statics: customerSchema_1.customerSeedCollectionMethods,
                }),
                message: 'Creating Customer Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.CreditAppSeeds,
                    schema: creditApplicationSchema_1.creditAppSeedSchema,
                    methods: creditApplicationSchema_1.creditAppSeedMethods,
                    statics: creditApplicationSchema_1.creditAppSeedCollectionMethods,
                }),
                message: 'Creating Credit Apllication Seed Data Collection',
            },
            {
                action: () => db.collection({
                    name: collections_1.CollectionNames.ContractSeeds,
                    schema: contractSeedSchema_1.contractSeedSchema,
                    methods: contractSeedSchema_1.contractSeedMethods,
                    statics: contractSeedSchema_1.contractSeedCollectionMethods,
                }),
                message: 'Creating Contract Seed Data Collection',
            },
            {
                action: () => {
                    const { seedFileCollectionMethods, seedFileMethods, seedFileSchema, } = seedFileSchema_1.default(seedJSONPath);
                    return db.collection({
                        name: collections_1.CollectionNames.SeedFiles,
                        schema: seedFileSchema,
                        methods: seedFileMethods,
                        statics: seedFileCollectionMethods,
                    });
                },
                message: 'Creating Seed File Collection',
            },
            // Setup default seed files
            {
                action: () => seedFiles_1.default(db),
                message: 'Setting Up Default Seed Files',
            },
            // Seed collections from json files
            {
                action: () => seedCompanyData_1.default(db),
                message: 'Populating Company Seed Data',
            },
            {
                action: () => seedUserData_1.default(db),
                message: 'Populating User Seed Data',
            },
            {
                action: () => seedOfficeData_1.default(db),
                message: 'Populating Office Seed Data',
            },
            {
                action: () => seedPriceGuideData_1.default(db),
                message: 'Populating Price Guide Seed Data',
            },
            {
                action: () => seedEstimateData_1.default(db),
                message: 'Populating Estimate Seed Data',
            },
            {
                action: () => seedContactData_1.default(db),
                message: 'Populating Contact Seed Data',
            },
            {
                action: () => seedAddressData_1.default(db),
                message: 'Populating Address Seed Data',
            },
            {
                action: () => seedCustomerData_1.default(db),
                message: 'Populating Customer Seed Data',
            },
            {
                action: () => seedCreditApplicationData_1.default(db),
                message: 'Populating Credit App Seed Data',
            },
            {
                action: () => seedContractData_1.default(db),
                message: 'Populating Contract Seed Data',
            },
            // If there's an active conneciton when the db loads, try connecting to
            // Parse and update status
            {
                action: () => __awaiter(void 0, void 0, void 0, function* () {
                    const activeQuery = db.parseconfigs.findOne({
                        selector: { active: { $eq: true } },
                    });
                    const activeConfig = yield activeQuery.exec();
                    if (activeConfig) {
                        activeConfig.connect();
                    }
                }),
                message: 'Loading Previously Active Connection',
            },
        ];
        // Itterate through and run loading actions. Dispatch status back to
        // db$ at the beginning of each run
        for (let i = 0; i < steps.length; i++) {
            const { action, message } = steps[i];
            const progress = Math.floor((i / steps.length) * 100);
            subscriber.next({
                message,
                progress,
            });
            try {
                yield action();
            }
            catch (e) {
                console.error(e, message);
                subscriber.next({ message: e.mesage, progress });
            }
        }
        subscriber.next({
            message: 'Leap Seed Database Scaffolded',
            progress: 100,
            db,
        });
        subscriber.complete();
    });
    createDB();
});
//# sourceMappingURL=database.js.map