"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.companySeedCollectionMethods = exports.companySeedMethods = exports.companySeedSchema = void 0;
const node_1 = __importDefault(require("parse/node"));
const company_1 = __importDefault(require("../../parse/models/company"));
exports.companySeedSchema = {
    title: 'Parse Config Schema',
    description: 'Connection information for the Parse/LeapOne Server',
    version: 0,
    keyCompression: true,
    type: 'object',
    properties: {
        id: {
            type: 'string',
            primary: true,
        },
        companyName: { type: 'string' },
        maxActiveUsers: { type: 'number' },
        officeName: { type: 'string' },
        username: { type: 'string' },
        password: { type: 'string' },
        nameFirst: { type: 'string' },
        nameLast: { type: 'string' },
        email: { type: 'string' },
    },
    required: [],
};
exports.companySeedMethods = {
    checkExists() {
        return __awaiter(this, void 0, void 0, function* () {
            const name = this.companyName;
            const query = new node_1.default.Query(company_1.default);
            query.equalTo('name', name);
            const result = yield query.first();
            return !!result;
        });
    },
    createCompany(maxActiveUsers, partnerTag) {
        return __awaiter(this, void 0, void 0, function* () {
            const { companyName, officeName, username, password, nameFirst, nameLast, email, } = this;
            return company_1.default.create({
                companyName,
                officeName,
                username,
                password,
                nameFirst,
                nameLast,
                email,
                maxActiveUsers,
                partnerTag,
            });
        });
    },
    getAccountCredentials() {
        const { username, password } = this;
        return { username, password };
    },
};
exports.companySeedCollectionMethods = {
    countAllDocuments() {
        return __awaiter(this, void 0, void 0, function* () {
            const allDocs = yield this.find().exec();
            return allDocs.length;
        });
    },
    getExisting() {
        return __awaiter(this, void 0, void 0, function* () {
            const parseQuery = new node_1.default.Query(company_1.default);
            parseQuery.limit(10000);
            const results = yield parseQuery.find({ useMasterKey: true });
            const nameStatement = results.map((company) => ({
                companyName: { $eq: company.get('name') },
            }));
            const query = this.find({
                selector: { $or: nameStatement },
            });
            return query.exec();
        });
    },
    getRandom() {
        return __awaiter(this, void 0, void 0, function* () {
            const parseQuery = new node_1.default.Query(company_1.default);
            parseQuery.limit(10000);
            const results = yield parseQuery.find({ useMasterKey: true });
            const nameStatement = results.map((company) => ({
                companyName: { $ne: company.get('name') },
            }));
            const uniqueCompanies = this.find({
                selector: {
                    $and: nameStatement,
                },
            });
            const count = (yield uniqueCompanies.exec()).length;
            if (count === 0)
                throw new Error('All seed companies have already been created!');
            const randId = Math.floor(Math.random() * count + 1);
            const query = this.findOne({
                selector: {
                    $and: nameStatement,
                },
                skip: randId - 1,
            });
            const companySeed = yield query.exec();
            if (companySeed) {
                return companySeed;
            }
            else {
                throw new Error('Could not get Company Seed');
            }
        });
    },
};
//# sourceMappingURL=companySeedSchema.js.map