"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.creditAppSeedCollectionMethods = exports.creditAppSeedMethods = exports.creditAppSeedSchema = void 0;
const creditApplication_1 = __importDefault(require("../../parse/models/creditApplication"));
exports.creditAppSeedSchema = {
    title: 'Parse Config Schema',
    description: 'Connection information for the Parse/LeapOne Server',
    version: 0,
    keyCompression: true,
    type: 'object',
    properties: {
        id: {
            type: 'string',
            primary: true,
        },
        appId: { type: 'string' },
        date: { type: 'string' },
        decision: {
            type: 'object',
            properties: {
                Decision: { type: 'string' },
                Default_Payment: { type: 'string' },
                Down_Payment: { type: 'string' },
                EPNI_Payment: { type: 'string' },
                Finance_Amount: { type: 'string' },
                Finance_Type: { type: 'string' },
                Rate: { type: 'string' },
                status: { type: 'string' },
                Term: { type: 'string' },
                Total_Amount: { type: 'string' },
            },
        },
        misc: { type: 'object' },
        request: {
            type: 'object',
            properties: {
                amount: { type: 'number' },
                appid: { type: 'number' },
                decision: { type: 'string' },
                error: { type: 'number' },
                payment: { type: 'number' },
                PrgmType: { type: 'string' },
                rate: { type: 'number' },
                refTaskNo: { type: 'number' },
                term: { type: 'number' },
            },
        },
        requestedAmount: { type: 'number' },
        source: { type: 'string' },
    },
};
exports.creditAppSeedMethods = {
    createCreditApp(company, createdBy, customer, token, partnerApp, sourceLogo) {
        return __awaiter(this, void 0, void 0, function* () {
            const { appId, date, decision, misc, request, requestedAmount, source, } = this;
            const options = {
                appId,
                date: new Date(date),
                decision,
                misc,
                request,
                requestedAmount,
                source,
                company,
                createdBy,
                customer,
                partnerApp,
                sourceLogo,
            };
            return creditApplication_1.default.create(options, token);
        });
    },
};
exports.creditAppSeedCollectionMethods = {
    countAllDocuments() {
        return __awaiter(this, void 0, void 0, function* () {
            const allDocs = yield this.find().exec();
            return allDocs.length;
        });
    },
    getRandom() {
        return __awaiter(this, void 0, void 0, function* () {
            const creditApps = this.find();
            const count = (yield creditApps.exec()).length;
            const randId = Math.floor(Math.random() * count + 1);
            const query = this.findOne({
                selector: { id: { $gt: 0 } },
                skip: randId - 1,
            });
            const creditAppSeed = yield query.exec();
            if (creditAppSeed) {
                return creditAppSeed;
            }
            else {
                throw new Error('Could not get Credit App Seed');
            }
        });
    },
};
//# sourceMappingURL=creditApplicationSchema.js.map