'use strict';
var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    function adopt(value) {
        return value instanceof P ? value : new P(function (resolve) {
            resolve(value);
        });
    }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator['throw'](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = this && this.__importDefault || function (mod) {
    return mod && mod.__esModule ? mod : { 'default': mod };
};
Object.defineProperty(exports, '__esModule', { value: true });
exports.estimateSeedCollectionMethods = exports.estimateSeedMethods = exports.estimateSeedSchema = void 0;
const path_1 = __importDefault(require('path'));
const estimate_1 = __importDefault(require('../../parse/models/estimate'));
const makeParseFile_1 = __importDefault(require('../../util/makeParseFile'));
const getRandom_1 = require('../../util/getRandom');
exports.estimateSeedSchema = {
    title: 'Estimate Seed Schema',
    description: 'Seed data for generating estimates',
    version: 0,
    keyCompression: true,
    type: 'object',
    properties: {
        id: {
            type: 'string',
            primary: true
        },
        activeProductCategories: {
            type: 'array',
            items: { type: 'string' }
        },
        addedMeasureSheetItems: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    category: { type: 'string' },
                    quantity: { type: 'number' },
                    additionalValues: { type: 'object' },
                    itemObjectId: { type: 'string' },
                    activeObjecttId: { type: 'string' },
                    isActive: { type: 'boolean' }
                },
                additionalProperties: true
            }
        },
        contractPDF: { type: 'string' },
        creditAppPDF: { type: 'string' },
        downPayment: { type: 'number' },
        financeAmount: { type: 'number' },
        isSale: { type: 'boolean' },
        leadResults: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    values: {
                        type: 'array',
                        items: { type: 'string' }
                    },
                    apiValue: { type: 'string' },
                    id: { type: 'number' },
                    order: { type: 'number' },
                    title: { type: 'string' },
                    shouldFetch: { type: 'boolean' },
                    inputType: { type: 'string' },
                    value: { type: 'string' },
                    endpoint: { type: 'string' },
                    required: { type: 'boolean' }
                }
            }
        },
        resultFullString: { type: 'string' },
        resultPDF: { type: 'string' },
        saleAmount: { type: 'number' },
        selectedEmailLinks: { type: 'object' }
    }
};
const testDocPath = path_1.default.join(__dirname, '../../../assets/test-doc.pdf');
exports.estimateSeedMethods = {
    createEstimate(office, company, contractPDFPath = testDocPath, contractVerifyPDFPath = testDocPath, creditAppPDFPath = testDocPath, proposalPDFPath = testDocPath, proposalVerifyPDFPath = testDocPath, reportPDFPath = testDocPath, resultPDFPath = testDocPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const docPrefix = getRandom_1.genRandomId();
            const {activeProductCategories, addedMeasureSheetItems, downPayment, financeAmount, isSale, leadResults, resultFullString, saleAmount, selectedEmailLinks} = this;
            const newEstimate = {
                activeProductCategories,
                addedMeasureSheetItems,
                availability: {},
                company,
                contractPDF: yield makeParseFile_1.default(contractPDFPath, `${ docPrefix }-contractPDF`),
                contractVerifyPDF: yield makeParseFile_1.default(contractVerifyPDFPath, `${ docPrefix }-contractVerifyPDF`),
                creditAppPDF: yield makeParseFile_1.default(creditAppPDFPath, `${ docPrefix }-creditAppPDF`),
                demoResult: 0,
                // docuSign: {},
                // docusignCompleted: {},
                // docusignEnvelopeIds: [],
                // docusignObjects: {},
                // docusignResponse: {},
                downPayment,
                financeAmount,
                isSale,
                leadResults,
                office,
                paymentRequest: {},
                proposalPDF: yield makeParseFile_1.default(proposalPDFPath, `${ docPrefix }-proposalPDF`),
                proposalVerifyPDF: yield makeParseFile_1.default(proposalVerifyPDFPath, `${ docPrefix }-proposalVerifyPDF`),
                reportPDF: yield makeParseFile_1.default(reportPDFPath, `${ docPrefix }-reportPDF`),
                resultFullString,
                resultLastPriceLeft: '',
                resultLeadResult: '',
                resultNote: '',
                resultPDF: yield makeParseFile_1.default(resultPDFPath, `${ docPrefix }-resultPDF`),
                saleAmount,
                selectedEmailLinks
            };
            return estimate_1.default.create(newEstimate);
        });
    }
};
exports.estimateSeedCollectionMethods = {
    countAllDocuments() {
        return __awaiter(this, void 0, void 0, function* () {
            const allDocs = yield this.find().exec();
            return allDocs.length;
        });
    },
    getRandom() {
        return __awaiter(this, void 0, void 0, function* () {
            const estimates = this.find();
            const count = (yield estimates.exec()).length;
            const randId = Math.floor(Math.random() * count + 1);
            const query = this.findOne({
                selector: { id: { $gt: 0 } },
                skip: randId - 1
            });
            const estimateSeed = yield query.exec();
            if (estimateSeed) {
                return estimateSeed;
            } else {
                throw new Error('Could not get Estimate Seed');
            }
        });
    }
};    //# sourceMappingURL=estimateSeedSchema.js.map
