"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.officeSeedCollectionMethods = exports.officeSeedMethods = exports.officeSeedSchema = void 0;
const node_1 = __importDefault(require("parse/node"));
const office_1 = __importDefault(require("../../parse/models/office"));
const company_1 = __importDefault(require("../../parse/models/company"));
exports.officeSeedSchema = {
    title: 'Parse Config Schema',
    description: 'Connection information for the Parse/LeapOne Server',
    version: 0,
    keyCompression: true,
    type: 'object',
    properties: {
        id: {
            type: 'string',
            primary: true,
        },
        name: { type: 'string' },
    },
    required: [],
};
exports.officeSeedMethods = {
    checkExists() {
        return __awaiter(this, void 0, void 0, function* () {
            const { name } = this;
            const query = new node_1.default.Query(office_1.default);
            query.equalTo('name', name);
            const result = yield query.first();
            return !!result;
        });
    },
    createOffice(company, token) {
        return __awaiter(this, void 0, void 0, function* () {
            const { name } = this;
            return office_1.default.create({ name }, company, token);
        });
    },
};
exports.officeSeedCollectionMethods = {
    countAllDocuments() {
        return __awaiter(this, void 0, void 0, function* () {
            const allDocs = yield this.find().exec();
            return allDocs.length;
        });
    },
    getExisting() {
        return __awaiter(this, void 0, void 0, function* () {
            const parseQuery = new node_1.default.Query(company_1.default);
            parseQuery.limit(10000);
            const results = yield parseQuery.find();
            const nameStatement = results.map((office) => ({
                name: { $eq: office.get('name') },
            }));
            const query = this.find({
                selector: { $or: nameStatement },
            });
            return query.exec();
        });
    },
    getRandom() {
        return __awaiter(this, void 0, void 0, function* () {
            const parseQuery = new node_1.default.Query(company_1.default);
            parseQuery.limit(10000);
            const results = yield parseQuery.find({ useMasterKey: true });
            const nameStatement = results.map((office) => ({
                name: { $ne: office.get('name') },
            }));
            const uniqueOffices = this.find({
                selector: { $and: nameStatement },
            });
            const count = (yield uniqueOffices.exec()).length;
            const randId = Math.floor(Math.random() * count + 1);
            const query = this.findOne({
                selector: { $and: nameStatement },
                skip: randId - 1,
            });
            const officeSeed = yield query.exec();
            if (officeSeed) {
                return officeSeed;
            }
            else {
                throw new Error('Could not get Office Seed');
            }
        });
    },
};
//# sourceMappingURL=officeSeedSchema.js.map