'use strict';
var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    function adopt(value) {
        return value instanceof P ? value : new P(function (resolve) {
            resolve(value);
        });
    }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator['throw'](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = this && this.__importDefault || function (mod) {
    return mod && mod.__esModule ? mod : { 'default': mod };
};
Object.defineProperty(exports, '__esModule', { value: true });
exports.parseConfigCollectionMethods = exports.parseConfigMethods = exports.parseConfigSchema = void 0;
const node_fetch_1 = __importDefault(require('node-fetch'));
const parse_1 = __importDefault(require('../../parse/index'));
exports.parseConfigSchema = {
    title: 'Parse Config Schema',
    description: 'Connection information for the Parse/LeapOne Server',
    version: 0,
    keyCompression: true,
    type: 'object',
    properties: {
        id: {
            type: 'string',
            primary: true
        },
        serverName: { type: 'string' },
        appId: { type: 'string' },
        jsKey: { type: 'string' },
        masterKey: { type: 'string' },
        serverUrl: { type: 'string' },
        active: { type: 'boolean' }
    },
    indexes: ['serverName'],
    required: [
        'appId',
        'masterKey',
        'serverUrl'
    ]
};
exports.parseConfigMethods = {
    // Class method to connect to parse server described in config
    connect() {
        return __awaiter(this, void 0, void 0, function* () {
            if (yield this.checkOnline()) {
                const oldConnection = yield this.collection.findOne({
                    selector: {
                        active: true,
                        id: { $ne: this.id }
                    }
                }).exec();
                if (oldConnection) {
                    yield oldConnection.update({ $set: { active: false } });
                }
                try {
                    const {appId, jsKey, masterKey, serverUrl} = this;
                    parse_1.default({
                        appId,
                        jsKey,
                        masterKey,
                        serverUrl
                    });
                    yield this.update({ $set: { active: true } });
                    return true;
                } catch (e) {
                    console.log(e);
                    return false;
                }
            }
            return false;
        });
    },
    // Class method pings the server and returns true if it responds
    checkOnline() {
        return __awaiter(this, void 0, void 0, function* () {
            const {serverUrl} = this;
            try {
                yield node_fetch_1.default(`${ serverUrl }/health`);
                return true;
            } catch (e) {
                console.log(e);
                return false;
            }
        });
    }
};
exports.parseConfigCollectionMethods = {
    // tslint:disable-next-line: object-literal-shorthand
    countAllDocuments() {
        return __awaiter(this, void 0, void 0, function* () {
            const allDocs = yield this.find().exec();
            return allDocs.length;
        });
    }
};    //# sourceMappingURL=parseConfigSchema.js.map
