"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.priceGuideSeedCollectionMethods = exports.priceGuideSeedMethods = exports.priceGuideSeedSchema = void 0;
const node_1 = __importDefault(require("parse/node"));
const measureSheetItem_1 = __importDefault(require("../../parse/models/measureSheetItem"));
const PriceItemSchema = {
    type: 'object',
    properties: {
        accessories: {
            type: 'array',
            items: { type: 'object', additionalProperties: true },
        },
        accessoriesPricesDict: {
            type: 'object',
            additionalProperties: true,
        },
        accessoryPrices: {
            type: 'array',
            items: { type: 'object', additionalProperties: true },
        },
        additionalDetails: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    cellType: { type: 'string' },
                    defaultValue: { type: 'string' },
                    inputType: { type: 'string' },
                    note: { type: 'string' },
                    objectId: { type: 'string' },
                    placeholder: { type: 'string' },
                    required: { type: 'boolean' },
                    shouldCopy: { type: 'boolean' },
                    title: { type: 'string' },
                },
            },
        },
        category: { type: 'string' },
        commissionable: { type: 'boolean' },
        disabledParents: { type: 'array', items: { type: 'string' } },
        displayTitle: { type: 'string' },
        identifier: { type: 'string' },
        info: { type: 'string' },
        isAccessory: { type: 'boolean' },
        itemCode: { type: 'string' },
        itemCodes: { type: 'object', additionalProperties: true },
        itemPrices: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    total: { type: 'number' },
                },
            },
        },
        measurementType: { type: 'string' },
        name: { type: 'string' },
        orderNumber: { type: 'number' },
        parArray: { type: 'array', items: { type: 'number' } },
        parentItem: { type: 'string' },
        percentagePrice: { type: 'boolean' },
        placeholders: {
            type: 'array',
            items: {
                type: 'object',
                properties: {
                    placeholder: { type: 'string' },
                    replacement: { type: 'string' },
                    id: { type: 'string' },
                },
            },
        },
        pricesDict: { type: 'object', additionalProperties: true },
        shouldShowSwitch: { type: 'number' },
        subCategory: { type: 'string' },
        subCategory2: { type: 'string' },
    },
};
exports.priceGuideSeedSchema = {
    title: 'Measure Sheet Seed Item Schema',
    description: 'Measuresheet item with their child price guide items',
    version: 0,
    keyCompression: true,
    type: 'object',
    properties: {
        id: {
            type: 'string',
            primary: true,
        },
        itemCount: { type: 'integer' },
        items: {
            type: 'array',
            items: PriceItemSchema,
        },
        category: { type: 'string' },
        subCategory: { type: 'string' },
        subSubCategory: { type: 'string' },
        subSubcategories: { type: 'string' },
        itemName: { type: 'string' },
        itemNote: { type: 'string' },
        measurementType: { type: 'string' },
        shouldShowSwitch: { type: 'boolean' },
        orderNumber: { type: 'number' },
    },
    required: [],
};
exports.priceGuideSeedMethods = {
    checkExists() {
        return __awaiter(this, void 0, void 0, function* () {
            const name = this.itemName;
            const query = new node_1.default.Query(measureSheetItem_1.default);
            query.equalTo('itemName', name);
            const result = yield query.first();
            return !!result;
        });
    },
    createPriceGuideItem(company, offices, token) {
        return __awaiter(this, void 0, void 0, function* () {
            const { category, itemName, itemNote, items, measurementType, orderNumber, shouldShowSwitch, subCategory, subSubcategories, subSubCategory, } = this;
            return measureSheetItem_1.default.create({
                company,
                category,
                includedOffices: offices,
                itemName,
                itemNote,
                items,
                measurementType,
                orderNumber,
                shouldShowSwitch,
                subCategory,
                subSubcategories,
                subSubCategory,
            }, company, offices, token);
        });
    },
};
// eslint-disable-next-line max-len
exports.priceGuideSeedCollectionMethods = {
    countAllDocuments() {
        return __awaiter(this, void 0, void 0, function* () {
            const allDocs = yield this.find().exec();
            return allDocs.length;
        });
    },
    getRandom(company) {
        return __awaiter(this, void 0, void 0, function* () {
            const parseQuery = new node_1.default.Query(measureSheetItem_1.default);
            parseQuery.equalTo('company', company).limit(10000);
            const results = yield parseQuery.find({ useMasterKey: true });
            const nameStatement = results.map((measureSheetItem) => ({
                itemName: { $ne: measureSheetItem.get('itemName') },
            }));
            const uniqueNamed = this.find({
                selector: { $and: nameStatement },
            });
            const count = (yield uniqueNamed.exec()).length;
            if (count === 0)
                throw new Error(
                // eslint-disable-next-line max-len
                'All seed measure sheet items have already been created in this company!');
            const randId = Math.floor(Math.random() * count + 1);
            const query = this.findOne({
                selector: { $and: nameStatement },
                skip: randId - 1,
            });
            const priceItem = yield query.exec();
            if (priceItem) {
                return priceItem;
            }
            else {
                throw new Error('Could not get Price Guide Seed Item');
            }
        });
    },
};
//# sourceMappingURL=priceGuideSeedSchema.js.map