"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graceful_fs_1 = __importDefault(require("graceful-fs"));
const path_1 = __importDefault(require("path"));
exports.default = (seedJSONPath = path_1.default.join(__dirname, '../../../seedJSON/')) => {
    const seedFileSchema = {
        title: 'Seed File Schema',
        description: 'The filename & last modified for the seed JSON data for each collection',
        version: 0,
        keyCompression: true,
        type: 'object',
        properties: {
            collectionName: { type: 'string', primary: true },
            fileLastModified: { type: 'string' },
            fileName: { type: 'string' },
        },
    };
    const getFileModifiedTime = (filePath) => new Promise((resolve, reject) => {
        graceful_fs_1.default.stat(filePath, (err, stats) => {
            if (err) {
                console.error(err);
                reject(err);
            }
            const { mtime } = stats;
            const modifiedTime = new Date(mtime);
            resolve(modifiedTime);
        });
    });
    const getFilePath = (fileName) => path_1.default.join(seedJSONPath, `${fileName}`);
    const readJSONFile = (location) => new Promise((resolve, reject) => {
        console.log(`Reading file ${location}`);
        try {
            graceful_fs_1.default.readFile(location, 'utf8', (error, data) => {
                if (error)
                    throw error;
                try {
                    console.log(`File read, parsing JSON`);
                    const parsedData = JSON.parse(data);
                    console.log('JSON parsed!');
                    resolve(parsedData);
                }
                catch (e) {
                    console.error(`${e.name}: ${e.message}`);
                    reject(e);
                    throw e;
                }
            });
        }
        catch (err) {
            reject(err);
            console.error(err);
            reject('An unkown error occured');
            throw err;
        }
    });
    const seedFileMethods = {
        readFile() {
            return __awaiter(this, void 0, void 0, function* () {
                const filePath = getFilePath(this.fileName);
                return readJSONFile(filePath);
            });
        },
        updateLastModified() {
            return __awaiter(this, void 0, void 0, function* () {
                const lastModified = yield getFileModifiedTime(getFilePath(this.fileName));
                return this.update({
                    $set: { fileLastModified: lastModified.toISOString() },
                });
            });
        },
        wasFileModified() {
            return __awaiter(this, void 0, void 0, function* () {
                // If we've never read the file before, return true
                if (this.fileLastModified === '') {
                    return true;
                }
                const prevModified = new Date(this.fileLastModified);
                const lastModified = yield getFileModifiedTime(getFilePath(this.fileName));
                return lastModified > prevModified;
            });
        },
    };
    const seedFileCollectionMethods = {
        countAllDocuments() {
            return __awaiter(this, void 0, void 0, function* () {
                const allDocs = yield this.find().exec();
                return allDocs.length;
            });
        },
    };
    return { seedFileSchema, seedFileCollectionMethods, seedFileMethods };
};
//# sourceMappingURL=seedFileSchema.js.map