"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.userSeedCollectionMethods = exports.userSeedMethods = exports.userSeedSchema = void 0;
const node_1 = __importDefault(require("parse/node"));
const user_1 = __importDefault(require("../../parse/models/user"));
exports.userSeedSchema = {
    title: 'Parse Config Schema',
    description: 'Connection information for the Parse/LeapOne Server',
    version: 0,
    keyCompression: true,
    type: 'object',
    properties: {
        id: {
            type: 'string',
            primary: true,
        },
        userName: { type: 'string' },
        email: { type: 'string' },
        nameFirst: { type: 'string' },
        nameLast: { type: 'string' },
        phoneNumber: { type: 'string' },
        licenseNumber: { type: 'number' },
        password: { type: 'string' },
    },
    required: [],
};
exports.userSeedMethods = {
    checkExists() {
        return __awaiter(this, void 0, void 0, function* () {
            const name = this.userName;
            const query = new node_1.default.Query(user_1.default);
            query.equalTo('username', name);
            const result = yield query.first();
            return !!result;
        });
    },
    createUser(office, token) {
        return __awaiter(this, void 0, void 0, function* () {
            const { email, licenseNumber, nameFirst, nameLast, password, phoneNumber, userName: username, } = this;
            return user_1.default.create({
                allowedOffices: [office.id],
                apiCredentials: [],
                email,
                licenseNumber,
                nameFirst,
                nameLast,
                office: office.id,
                password,
                phoneNumber,
                username,
            }, token);
        });
    },
    getAccountCredentials() {
        const { userName: username, password } = this;
        return { username, password };
    },
};
exports.userSeedCollectionMethods = {
    countAllDocuments() {
        return __awaiter(this, void 0, void 0, function* () {
            const allDocs = yield this.find().exec();
            return allDocs.length;
        });
    },
    getExisting() {
        return __awaiter(this, void 0, void 0, function* () {
            const parseQuery = new node_1.default.Query(user_1.default);
            parseQuery.limit(10000);
            const results = yield parseQuery.find();
            const nameStatement = results.map((user) => ({
                userName: { $eq: user.get('username') },
            }));
            const query = this.find({
                selector: { $or: nameStatement },
            });
            return query.exec();
        });
    },
    getRandom() {
        return __awaiter(this, void 0, void 0, function* () {
            const parseQuery = new node_1.default.Query(user_1.default);
            parseQuery.limit(10000);
            const results = yield parseQuery.find({ useMasterKey: true });
            const nameStatement = results.map((user) => ({
                userName: { $ne: user.get('username') },
            }));
            const uniqueQuery = this.find({
                selector: { $and: nameStatement },
            });
            const count = (yield uniqueQuery.exec()).length;
            if (count === 0)
                throw new Error('All seed users have already been created!');
            const randId = Math.floor(Math.random() * count + 1);
            const query = this.findOne({
                selector: { $and: nameStatement },
                skip: randId - 1,
            });
            const userSeed = yield query.exec();
            if (userSeed) {
                return userSeed;
            }
            else {
                throw new Error('Error getting user seed!');
            }
        });
    },
};
//# sourceMappingURL=userSeedSchema.js.map