"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.seedCollection = void 0;
exports.seedCollection = (db, collection, typeguard) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const docCount = yield ((_a = db[collection]) === null || _a === void 0 ? void 0 : _a.countAllDocuments());
    const seedFileDoc = yield db.seedfiles.findOne(collection).exec();
    if (seedFileDoc) {
        const modified = yield seedFileDoc.wasFileModified();
        // If the collection is empty, or the file has changed since last processed,
        // seed the database
        if (docCount === 0 || modified) {
            // Process JSON file into JS
            let seedData;
            try {
                seedData = yield seedFileDoc.readFile();
            }
            catch (e) {
                throw new Error(`Failed to parse ${collection} json. ${e.message}`);
            }
            // Make sure the data is type safe
            if (typeguard(seedData)) {
                // If there's exisitng data, clear it before re-seeding
                if (docCount !== 0) {
                    const existingDocs = yield db[collection].find().exec();
                    if (Array.isArray(existingDocs)) {
                        yield Promise.all(existingDocs.map((doc) => doc.remove()));
                    }
                }
                // Seed DB
                const seedDocs = seedData.map((seed, index) => (Object.assign({ id: index.toString() }, seed)));
                try {
                    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                    // @ts-ignore
                    const results = yield db[collection].bulkInsert(seedDocs);
                    console.log(
                    // eslint-disable-next-line max-len
                    `Import results for ${collection}, ${seedDocs.length} items - success: ${results.success.length} error: ${results.error.length}`);
                }
                catch (e) {
                    console.error(e);
                }
                // Record the time data was parsed to check against file rev in future
                yield seedFileDoc.updateLastModified();
            }
        }
    }
});
//# sourceMappingURL=seedCollection.js.map