"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const seedCollection_1 = require("./seedCollection");
const collections_1 = require("../types/collections");
const isContractSeedData = (seedData) => {
    return (Array.isArray(seedData) &&
        seedData
            .map((item) => {
            const { author, canAddMultiplePages, category, contractData, displayName, excludedStates, hMargin, iconBackgroundColor, isCorporateTemplate, isTemplate, order, pageId, pageSize, photosPerPage, type, updatedAt, wMargin, } = item;
            const validFields = [
                ['author', typeof author === 'string'],
                ['canAddMultiplePages', typeof canAddMultiplePages === 'boolean'],
                ['category', typeof category === 'string'],
                ['contractData', typeof contractData === 'object'],
                ['displayName', typeof displayName === 'string'],
                [
                    'excludedStates',
                    !!(Array.isArray(excludedStates) &&
                        excludedStates.reduce((acc, val) => acc && typeof val === 'string', true)),
                ],
                ['hMargin', typeof hMargin === 'number'],
                [
                    'iconBackgroundColor',
                    !!(Array.isArray(iconBackgroundColor) &&
                        iconBackgroundColor.reduce((acc, val) => acc && typeof val === 'number', true)),
                ],
                ['isCorporateTemplate', typeof isCorporateTemplate === 'boolean'],
                ['isTemplate', typeof isTemplate === 'boolean'],
                ['order', typeof order === 'number'],
                ['pageId', typeof pageId === 'string'],
                ['pageSize', typeof pageSize === 'string'],
                ['photosPerPage', typeof photosPerPage === 'number'],
                ['type', typeof type === 'string'],
                ['updatedAt', typeof updatedAt === 'string'],
                ['wMargin', typeof wMargin === 'number'],
            ];
            let invalidField = null;
            validFields.forEach((field) => {
                if (!field[1]) {
                    const key = field[0];
                    invalidField = `{${key}: ${item[key]}}`;
                }
            });
            if (invalidField) {
                throw new Error(`Invalid field: ${invalidField}`);
            }
            return invalidField === null;
        })
            .reduce((previous, current) => {
            if (current)
                return previous;
            return false;
        }, true));
};
const seedContractData = (db) => __awaiter(void 0, void 0, void 0, function* () {
    return seedCollection_1.seedCollection(db, collections_1.CollectionNames.ContractSeeds, isContractSeedData);
});
exports.default = seedContractData;
//# sourceMappingURL=seedContractData.js.map