"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const collections_1 = require("../types/collections");
const blankMeasureSheetItem = {
    itemCount: 0,
    items: [],
    category: '',
    subCategory: '',
    subSubCategory: '',
    subSubcategories: '',
    itemName: '',
    itemNote: '',
    measurementType: '',
    shouldShowSwitch: true,
    orderNumber: 0,
};
const blankPriceItem = {
    accessories: [],
    accessoriesPricesDict: {},
    accessoryPrices: [],
    additionalDetails: [],
    category: '',
    commissionable: false,
    disabledParents: [],
    displayTitle: '',
    identifier: '',
    info: '',
    isAccessory: false,
    itemCode: '',
    itemCodes: {},
    itemPrices: [],
    measurementType: '',
    name: '',
    orderNumber: 0,
    parArray: [],
    parentItem: '',
    percentagePrice: false,
    placeholders: [],
    pricesDict: {},
    shouldShowSwitch: 0,
    subCategory: '',
    subCategory2: '',
};
const isPriceGuideSeedData = (seedData) => {
    return (Array.isArray(seedData) &&
        seedData
            .map((seed) => {
            const valid = typeof seed.category === 'string' &&
                typeof seed.itemName === 'string' &&
                typeof seed.measurementType === 'string';
            if (!valid)
                console.log('bad item', seed);
            return valid;
        })
            .reduce((previous, current) => {
            if (current)
                return previous;
            return false;
        }, true));
};
const seedCompanyData = (db) => __awaiter(void 0, void 0, void 0, function* () {
    const docCount = yield db.priceguideseeds.countAllDocuments();
    const collection = collections_1.CollectionNames.PriceGuideSeeds;
    const seedFileDoc = yield db.seedfiles.findOne(collection).exec();
    if (seedFileDoc) {
        const modified = yield seedFileDoc.wasFileModified();
        // If the collection is empty, or the file has changed since last processed,
        // seed the database
        if (docCount === 0 || modified) {
            if (docCount !== 0) {
                const existingDocs = yield db[collection].find().exec();
                // Temporarilly ignoring, don't have timne to write propper typing
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-ignore
                yield Promise.all(existingDocs.map((doc) => doc.remove()));
            }
            let priceGuideSeedData;
            try {
                priceGuideSeedData = yield seedFileDoc.readFile();
                // Fill out missing fields and remove erranous ones in seed data
                priceGuideSeedData =
                    Array.isArray(priceGuideSeedData) &&
                        priceGuideSeedData.map(({ category, itemCount, itemName, itemNote, items, measurementType, orderNumber, shouldShowSwitch, subCategory, subSubCategory, subSubcategories, }) => (Object.assign(Object.assign({}, blankMeasureSheetItem), { category,
                            itemCount,
                            itemName,
                            itemNote, items: Array.isArray(items)
                                ? items.map(({ accessories, accessoriesPricesDict, accessoryPrices, additionalDetails, 
                                // eslint-disable-next-line no-shadow
                                category, commissionable, disabledParents, displayTitle, identifier, info, isAccessory, itemCode, itemCodes, itemPrices, 
                                // eslint-disable-next-line no-shadow
                                measurementType, name, 
                                // eslint-disable-next-line no-shadow
                                orderNumber, parArray, parentItem, percentagePrice, placeholders, pricesDict, 
                                // eslint-disable-next-line no-shadow
                                shouldShowSwitch, 
                                // eslint-disable-next-line no-shadow
                                subCategory, subCategory2, }) => (Object.assign(Object.assign({}, blankPriceItem), { accessories,
                                    accessoriesPricesDict,
                                    accessoryPrices,
                                    additionalDetails,
                                    category,
                                    commissionable,
                                    disabledParents,
                                    displayTitle,
                                    identifier,
                                    info,
                                    isAccessory,
                                    itemCode,
                                    itemCodes, itemPrices: Array.isArray(itemPrices)
                                        ? itemPrices.map(({ total = 0 }) => ({
                                            total: total || 0,
                                        }))
                                        : [], measurementType,
                                    name,
                                    orderNumber,
                                    parArray,
                                    parentItem,
                                    percentagePrice, placeholders: Array.isArray(placeholders)
                                        ? placeholders.map(({ id = '', placeholder = '', replacement = '', }) => ({
                                            id,
                                            placeholder,
                                            replacement,
                                        }))
                                        : [], pricesDict,
                                    shouldShowSwitch,
                                    subCategory,
                                    subCategory2 })))
                                : [], measurementType,
                            orderNumber,
                            shouldShowSwitch,
                            subCategory,
                            subSubCategory,
                            subSubcategories })));
            }
            catch (e) {
                console.log('Failed to parse priceguide json. ', e);
            }
            if (isPriceGuideSeedData(priceGuideSeedData)) {
                const seedDocs = priceGuideSeedData.map((pgs, index) => (Object.assign({ id: index.toString() }, pgs)));
                for (let i = 0; i < seedDocs.length; i += 1000) {
                    const batch = seedDocs.slice(i, i + 1000);
                    const results = yield db[collection].bulkInsert(batch);
                    console.log(
                    // eslint-disable-next-line max-len
                    `Import results for ${collection}, ${i + batch.length} of ${seedDocs.length} - success: ${results.success.length} error: ${results.error.length}`);
                }
                yield seedFileDoc.updateLastModified();
            }
        }
    }
});
exports.default = seedCompanyData;
//# sourceMappingURL=seedPriceGuideData.js.map