/// <reference types="parse" />
import Parse from 'parse/node';
import User from './user';
import Office from './office';
import Company from './company';
export declare enum ImagesSource {
    CompanyLogo = "companyLogo",
    Default = "default",
    EmptySpace = "emptySpace",
    Image = "image"
}
export interface AdditionalLine {
    objectId?: string;
    underline: boolean;
    value: string;
    note: string;
    valueFontSize: number;
    valueFontBold: boolean;
    noteFontSize: number;
    noteFontBold: boolean;
    valueFontUnderline?: boolean;
    valueFontName?: string;
    valueFontColor?: string;
    noteFontUnderline?: boolean;
    noteFontName?: string;
    noteFontColor?: string;
    websiteTitle?: string;
}
export declare enum CellType {
    BankAccountCell = "bankAccountCell",
    CreditCardCell = "creditCardCell",
    DetailCell = "detailCell",
    Drawing = "drawing",
    EmptySpace = "emptySpace",
    Header = "header",
    ImagePicker = "imagePicker",
    MeasureSheetItemDetail = "measureSheetItemDetail",
    PhotoPickerCell = "photoPickerCell",
    Provia = "provia",
    Signatures = "signatures",
    Switched = "switched",
    TextLong = "textLong",
    TextOnly = "textOnly",
    TextShort = "textShort",
    TextXLong = "textXLong"
}
export declare enum DetailItemImagesSource {
    Default = "default",
    Unique = "unique"
}
export interface LinkedMeasureSheetItemConfig {
    quantity: boolean;
    unitTotal: boolean;
    title: boolean;
    subtitle: boolean;
    measurementType: boolean;
    total: boolean;
}
export interface DetailItem {
    allowReportPhotos?: boolean;
    appNote?: string;
    appOnly: boolean;
    appTitle?: string;
    cellId?: string;
    cellType: CellType;
    clearValueIfZero?: boolean;
    contractTitle?: string;
    defaultImageId?: string;
    detailItems?: [];
    disableImageLink?: boolean;
    drawIfEmpty: boolean;
    dynamicInputType?: DynamicInputType;
    emptySpaceHeight?: number;
    emptyValue?: string;
    formula?: string;
    formulaWhole?: string;
    fractionDigits?: string;
    hidden?: boolean;
    imageHeight: number;
    images?: Parse.File[];
    imagesSource?: DetailItemImagesSource;
    initialsNote?: string;
    initialsRequired: boolean;
    inputDisabled?: boolean;
    inputType: string;
    isTotalSaleAmount?: boolean;
    linkedMeasureSheetItem?: string;
    linkedMeasureSheetItemConfig?: LinkedMeasureSheetItemConfig;
    measueSheetItemTotalIds?: string[];
    measureSheetItemQuantityIds?: [];
    multiSelectorSeparator?: string;
    objectId?: string;
    pickerValues: string[];
    required: boolean;
    signatures?: [];
    switchValueOff: string;
    switchValueOn: string;
    titleFontBold: boolean;
    titleFontColor?: string;
    titleFontName?: string;
    titleFontSize: number;
    titleFontUnderline?: boolean;
    titleLinked?: boolean;
    value?: string;
    valueFontBold: boolean;
    valueFontColor?: string;
    valueFontName?: string;
    valueFontSize: number;
    valueFontUnderline?: boolean;
    websiteTitle?: string;
}
export interface Header {
    websiteTitle?: string;
    appTitle: string;
    title: string;
    titleFontName?: string;
    titleFontSize?: number;
    titleFontBold?: boolean;
    titleFontColor?: string;
    titleFontUnderline?: boolean;
    border: number | string;
    cellItems: HeaderCellItem[][];
    objectId?: string;
}
export interface Signature {
    objectId?: string;
    appNote: string;
    contractNote: string;
    contractNoteFontSize: number;
    contractNoteBold: boolean;
    contractNoteUnderline?: boolean;
    contractNoteFontName?: string;
    contractNoteFontColor?: string;
    footerNote: string;
    underline: boolean;
    column: number;
    additionalLines: AdditionalLine[];
    websiteTitle?: string;
}
export interface DynamicInputType {
    cellId?: null | string;
    objects: Record<string, unknown>[];
}
export interface PurpleCellItem {
    allowReportPhotos?: boolean;
    appNote?: string;
    appOnly: boolean;
    appTitle?: string;
    cellId?: null | string;
    cellType: CellType;
    clearValueIfZero?: boolean;
    contractTitle?: string;
    defaultImageId?: string;
    detailItems?: DetailItem[];
    disableImageLink?: boolean;
    drawIfEmpty: boolean;
    dynamicInputType?: DynamicInputType;
    emptySpaceHeight?: number;
    emptyValue?: string;
    formula?: string;
    formulaWhole?: string;
    fractionDigits?: string;
    header?: Header;
    hidden?: boolean;
    imageHeight: number;
    images?: [];
    imagesSource?: ImagesSource;
    initialsNote?: string;
    initialsRequired: boolean;
    inputDisabled?: boolean;
    inputType: string;
    isTotalSaleAmount?: boolean;
    linkedMeasureSheetItem?: string;
    linkedMeasureSheetItemConfig?: LinkedMeasureSheetItemConfig;
    measueSheetItemTotalIds?: string[];
    measureSheetItemId?: string;
    measureSheetItemQuantityIds?: string[];
    measureSheetItemTotalIds?: string[];
    multiSelectorSeparator?: string;
    objectId?: string;
    pickerValues: string[];
    required: boolean;
    signatures?: Signature[];
    switchValueOff: string;
    switchValueOn: string;
    titleFontBold: boolean;
    titleFontColor?: string;
    titleFontName?: string;
    titleFontSize: number;
    titleFontUnderline?: boolean;
    titleLinked?: boolean;
    value?: string;
    valueFontBold: boolean;
    valueFontColor?: string;
    valueFontName?: string;
    valueFontSize: number;
    valueFontUnderline?: boolean;
    websiteTitle?: string;
}
export interface HeaderCellItem {
    alignment: number;
    cellType: ImagesSource;
    emptySpaceHeight: number;
    fontBold: boolean;
    fontColor?: string;
    fontName?: string;
    fontSize: number;
    fontUnderline?: boolean;
    image?: [] | File;
    logoHeight: number;
    objectId?: string;
    value: string;
}
export interface IBaseContractObject {
    author: string;
    canAddMultiplePages: boolean;
    category: string;
    contractData: {
        objectId: string;
        data: {
            additionalLines?: AdditionalLine[];
            appNote?: string;
            appTitle?: string;
            border?: number | string;
            canAddMultiple?: boolean;
            cellItems?: (HeaderCellItem[] | PurpleCellItem[])[];
            column?: number;
            contractNote?: string;
            contractNoteBold?: boolean;
            contractNoteFontColor?: string;
            contractNoteFontName?: string;
            contractNoteFontSize?: number;
            contractNoteUnderline?: boolean;
            contractTitle?: string;
            drawBorder?: boolean;
            fontBold?: boolean;
            fontColor?: string;
            fontName?: string;
            fontSize?: number;
            fontUnderline?: boolean;
            footerNote?: string;
            linkedMeasureSheetItemIds?: string[];
            newPage?: boolean;
            objectId?: string;
            shading?: number;
            title?: string;
            titleFontBold?: boolean;
            titleFontColor?: string;
            titleFontName?: string;
            titleFontSize?: number;
            titleFontUnderline?: boolean;
            underline?: boolean;
            userInputRequired?: boolean;
            websiteTitle?: string;
        }[];
        groupType: 'body' | 'header' | 'signature';
    }[];
    displayName: string;
    excludedStates: string[];
    hMargin: number;
    iconBackgroundColor: number[];
    isCorporateTemplate: boolean;
    isTemplate: boolean;
    order: number;
    pageId: string;
    pageSize: string;
    photosPerPage: number;
    type: string;
    updatedAt: Date;
    useWatermark?: boolean;
    watermarkAlpha?: number;
    watermarkWidthPercent?: number;
    wMargin: number;
}
export interface IMockContractObject extends IBaseContractObject {
    company: Company;
    file: Parse.File;
    iconImage?: Parse.File;
    iconImageThumb: Parse.File;
    images: Parse.File[];
    includedOffices: Office[];
    lastModifiedBy: User;
    pdf?: Parse.File;
    pdfThumbnail?: Parse.File;
    preview?: Parse.File;
    watermark?: Parse.File;
}
declare class ContractObject extends Parse.Object {
    constructor(options?: IMockContractObject);
    static create(mockContract: IMockContractObject, sessionToken: string): Promise<ContractObject>;
}
export default ContractObject;
//# sourceMappingURL=contractObject.d.ts.map