'use strict';
var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    function adopt(value) {
        return value instanceof P ? value : new P(function (resolve) {
            resolve(value);
        });
    }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator['throw'](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = this && this.__importDefault || function (mod) {
    return mod && mod.__esModule ? mod : { 'default': mod };
};
Object.defineProperty(exports, '__esModule', { value: true });
/* eslint-disable max-lines */
/* eslint-disable no-underscore-dangle */
const graceful_fs_1 = __importDefault(require('graceful-fs'));
const moment_1 = __importDefault(require('moment'));
const path_1 = __importDefault(require('path'));
const node_1 = __importDefault(require('parse/node'));
const getSessionToken_1 = __importDefault(require('../parse/helpers/getSessionToken'));
const user_1 = __importDefault(require('../parse/models/user'));
const office_1 = __importDefault(require('../parse/models/office'));
const company_1 = __importDefault(require('../parse/models/company'));
const partnerCreditApplication_1 = __importDefault(require('../parse/models/partnerCreditApplication'));
const measureSheetItem_1 = __importDefault(require('../parse/models/measureSheetItem'));
const getRandom_1 = require('./getRandom');
const contractObject_1 = __importDefault(require('../parse/models/contractObject'));
const consoleTimer_1 = require('./consoleTimer');
const makeParseFile_1 = __importDefault(require('./makeParseFile'));
const generateRandCompany = (companySeed, consoleLog, db, noContracts, noCreditApps, noEstimates, noMeasureItems, noOffices, noUsers, partnerTag, creditLogoPath = path_1.default.join(__dirname, '../../assets/test-credit-logo.png'), testPDFPath = path_1.default.join(__dirname, '../../assets/test-doc.pdf')) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b;
    try {
        // Get our test assets from disk and create Parse file objects
        const creditLogoFile = yield makeParseFile_1.default(creditLogoPath, 'test-credit-logo.png');
        const testPdfFile = yield makeParseFile_1.default(testPDFPath, 'test-doc.pdf');
        const testPdfThumbnailUrl = path_1.default.resolve(__dirname, '../../assets/test-doc.png');
        const testPdfThumbnail = graceful_fs_1.default.readFileSync(testPdfThumbnailUrl, { encoding: 'base64' });
        const testPdfThumbnailFile = new node_1.default.File('test-doc.png', { base64: testPdfThumbnail });
        consoleLog('Creating company');
        const createCompanyStart = consoleTimer_1.getNow();
        const {companyName, officeName, username, password, nameFirst, nameLast, email} = companySeed;
        const company = yield company_1.default.create({
            companyName,
            officeName,
            username,
            password,
            nameFirst,
            nameLast,
            email,
            maxActiveUsers: Number(noUsers),
            partnerTag
        });
        const initialOffice = company.get('offices')[0];
        const iUserQuery = new node_1.default.Query(user_1.default);
        iUserQuery.equalTo('company', company);
        const initialUser = yield iUserQuery.first({ useMasterKey: true });
        consoleLog(`Company: ${ company.get('name') }, created with Office: ${ initialOffice.get('name') }, and User: ${ initialUser === null || initialUser === void 0 ? void 0 : initialUser.get('username') }`, 'success');
        consoleTimer_1.getDuration(createCompanyStart, 'Create Company');
        const sessionToken = yield getSessionToken_1.default(username, password);
        const offices = [initialOffice];
        const users = [initialUser];
        const userSeeds = [];
        consoleLog(`Creating ${ noOffices } Office(s)`);
        yield Promise.all(// exclude intiial office created w/company
        [...Array(noOffices - 1)].map((value, index) => __awaiter(void 0, void 0, void 0, function* () {
            const getRandOfficeStart = consoleTimer_1.getNow();
            const officeSeed = yield db.officeseeds.getRandom();
            consoleTimer_1.getDuration(getRandOfficeStart, 'Get Random Office Seed');
            consoleLog(`Creating office (${ index + 1 }/${ noOffices }): ${ officeSeed.name }`);
            const createOfficeStart = consoleTimer_1.getNow();
            const office = yield officeSeed.createOffice(company, sessionToken);
            offices.push(office);
            consoleLog(`Office ${ office.get('name') } created!`, 'success');
            consoleTimer_1.getDuration(createOfficeStart, 'Rand Office Created');
        })));
        consoleLog(`Creating ${ noUsers } User(s)`);
        // Account for intial admin user & office created w/company
        const usersNo = noUsers - 1;
        const usersPerOffice = Math.floor(usersNo / noOffices);
        const remainder = usersNo % noOffices;
        const createUser = office => __awaiter(void 0, void 0, void 0, function* () {
            const getUserSeed = consoleTimer_1.getNow();
            const userSeed = yield db.userseeds.getRandom();
            userSeeds.push(userSeed);
            consoleTimer_1.getDuration(getUserSeed, 'Get User Seed');
            consoleLog(`Creating user: ${ userSeed.userName }`);
            const createUserStart = consoleTimer_1.getNow();
            const user = yield userSeed.createUser(office, sessionToken);
            consoleTimer_1.getDuration(createUserStart, 'Create Parse User');
            users.push(user);
            consoleLog(`User: ${ userSeed.userName } added to office: ${ office.get('name') }`, 'success');
        });
        if (usersNo > 0) {
            for (const office of offices) {
                for (let i = 0; i < usersPerOffice; i++) {
                    yield createUser(office);
                }
            }
            // Put all remainder users in initial company office
            if (remainder) {
                for (let i = 0; i < remainder; i++) {
                    yield createUser(offices[0]);
                }
            }
        }
        consoleLog(`Creating ${ noMeasureItems } Measuresheet Item(s)`);
        const measureSheetItems = [];
        for (let i = 0; i < noMeasureItems; i++) {
            const randPriceSeedStart = consoleTimer_1.getNow();
            const {category, itemName, itemNote, items, measurementType, orderNumber, shouldShowSwitch, subCategory, subSubCategory, subSubcategories} = yield db.priceguideseeds.getRandom(company);
            consoleTimer_1.getDuration(randPriceSeedStart, 'Get Radom Measuresheet Item Seed');
            consoleLog(// eslint-disable-next-line max-len
            `Creating Measuresheet Item (${ i + 1 }/${ noMeasureItems }) "${ itemName }" with ${ items.length } Priceguide Item(s)`);
            const createMSSstart = consoleTimer_1.getNow();
            const measureSheetItem = yield measureSheetItem_1.default.create({
                company,
                category,
                includedOffices: offices,
                itemName,
                itemNote,
                items,
                measurementType,
                orderNumber,
                shouldShowSwitch,
                subCategory,
                subSubCategory,
                subSubcategories
            }, company, offices, sessionToken);
            consoleTimer_1.getDuration(createMSSstart, 'Create Measuresheet Item');
            measureSheetItems.push(measureSheetItem);
            consoleLog(`Measuresheet Item "${ measureSheetItem.get('itemName') }" created`, 'success');
        }
        const customers = [];
        for (let i = 0; i < noEstimates; i++) {
            consoleLog(`Creating estimate (${ i + 1 }/${ noEstimates })`);
            const newCustomerStart = consoleTimer_1.getNow();
            const randUserIndex = getRandom_1.getRand(users.length - 1);
            const creator = yield (_a = users[randUserIndex]) === null || _a === void 0 ? void 0 : _a.fetch({ useMasterKey: true });
            const officeIds = creator === null || creator === void 0 ? void 0 : creator.get('allowedOffices');
            const officeId = officeIds[getRandom_1.getRand(officeIds.length - 1)];
            const office = new office_1.default();
            office.id = officeId;
            let userName;
            let passwd;
            if (randUserIndex === 0) {
                [userName, passwd] = [
                    username,
                    password
                ];
            } else {
                const _username = creator === null || creator === void 0 ? void 0 : creator.getUsername();
                const userDoc = yield db.userseeds.findOne().where('userName').equals(_username).exec();
                if (userDoc) {
                    ({
                        userName,
                        password: passwd
                    } = userDoc);
                } else {
                    [userName, passwd] = [
                        '',
                        ''
                    ];
                }
            }
            if (userName !== '' && passwd !== '' && creator) {
                const token = yield getSessionToken_1.default(userName, passwd);
                const contactEmailSeed = yield db.contactseeds.getRandom(2);
                const contactEmail = yield contactEmailSeed.createContact(company, token);
                const contactPhoneSeed = yield db.contactseeds.getRandom(1);
                const contactPhone = yield contactPhoneSeed.createContact(company, token);
                const addressSeed = yield db.addressseeds.getRandom();
                const address = yield addressSeed.createAddress(company, token);
                const estimateSeed = yield db.estimateseeds.getRandom();
                const estimate = yield estimateSeed.createEstimate(office, company);
                const customerSeed = yield db.customerseeds.getRandom();
                consoleTimer_1.getDuration(newCustomerStart, 'Build Customer from Random Seed');
                try {
                    const createCustomerStart = consoleTimer_1.getNow();
                    const customer = yield customerSeed.createCustomer(contactPhone, contactEmail, address, estimate, company, creator, token);
                    consoleTimer_1.getDuration(createCustomerStart, 'Create Customer');
                    customers.push(customer);
                } catch (error) {
                    consoleLog(error, 'danger');
                    throw error;
                }
            }
            const partnerCreditAppQuery = new node_1.default.Query(partnerCreditApplication_1.default);
            const partnerCreditApps = yield partnerCreditAppQuery.find({ useMasterKey: true });
            const creditApps = [];
            for (let i = 0; i < noCreditApps; i++) {
                const getRandCreditApp = consoleTimer_1.getNow();
                const creditAppDoc = yield db.creditappseeds.getRandom();
                const creator = users[getRandom_1.getRand(users.length - 1)];
                const customer = customers[getRandom_1.getRand(customers.length - 1)];
                const partnerApp = partnerCreditApps[getRandom_1.getRand(partnerCreditApps.length - 1)];
                consoleTimer_1.getDuration(getRandCreditApp, 'Get Random Credit App');
                const createCreditAppStart = consoleTimer_1.getNow();
                if (creator) {
                    const creditApp = yield creditAppDoc.createCreditApp(company, creator, customer, sessionToken, partnerApp, creditLogoFile);
                    consoleTimer_1.getDuration(createCreditAppStart, 'Create Credit App');
                    creditApps.push(creditApp);
                }
            }
            consoleLog(`Creating ${ noContracts } contract(s)`);
            const contracts = [];
            for (let i = 0; i < noContracts; i++) {
                consoleLog(`Creating contract (${ i + 1 }/${ noEstimates })`, 'success');
                const getRandContractStart = consoleTimer_1.getNow();
                const randUserIndex = getRandom_1.getRand(users.length - 1);
                const creator = yield (_b = users[randUserIndex]) === null || _b === void 0 ? void 0 : _b.fetch({ useMasterKey: true });
                if (creator) {
                    let [userName, passwd] = [
                        '',
                        ''
                    ];
                    if (randUserIndex === 0) {
                        userName = username;
                        passwd = password;
                    } else {
                        const _username = creator === null || creator === void 0 ? void 0 : creator.getUsername();
                        const userDoc = yield db.userseeds.findOne().where('userName').equals(_username).exec();
                        if (userDoc) {
                            ({
                                userName,
                                password: passwd
                            } = userDoc);
                        }
                    }
                    const token = yield getSessionToken_1.default(userName, passwd);
                    const _offices = creator.get('allowedOffices');
                    const {author, canAddMultiplePages, category, contractData, displayName, excludedStates, hMargin, iconBackgroundColor, isCorporateTemplate, isTemplate, order, pageId, pageSize, photosPerPage, type, updatedAt, useWatermark, watermarkAlpha, watermarkWidthPercent, wMargin} = yield db.contractseeds.getRandom();
                    const mockContract = {
                        author,
                        canAddMultiplePages,
                        category,
                        // swap measuresheet item ids for ones on this company
                        contractData: contractData.map(cdata => Object.assign(Object.assign({}, cdata), {
                            data: cdata.data.map(data => Object.assign(Object.assign({}, data), {
                                linkedMeasureSheetItemIds: Array.isArray(data.linkedMeasureSheetItemIds) && data.linkedMeasureSheetItemIds.length > 0 ? data.linkedMeasureSheetItemIds.map(() => {
                                    const randMS = measureSheetItems[getRandom_1.getRand(measureSheetItems.length - 1)];
                                    return randMS.id;
                                }) : []
                            }))
                        })),
                        company,
                        displayName,
                        excludedStates,
                        file: testPdfFile,
                        hMargin,
                        iconBackgroundColor,
                        iconImageThumb: testPdfThumbnailFile,
                        images: [],
                        includedOffices: _offices,
                        isCorporateTemplate,
                        isTemplate,
                        lastModifiedBy: creator,
                        order,
                        pageId,
                        pageSize,
                        pdf: testPdfFile,
                        pdfThumbnail: testPdfThumbnailFile,
                        photosPerPage,
                        preview: testPdfThumbnailFile,
                        type,
                        updatedAt,
                        useWatermark,
                        watermarkAlpha,
                        watermarkWidthPercent,
                        wMargin
                    };
                    consoleTimer_1.getDuration(getRandContractStart, 'Get Random Contract Seed');
                    const createContractStart = consoleTimer_1.getNow();
                    const contract = yield contractObject_1.default.create(mockContract, token);
                    consoleTimer_1.getDuration(createContractStart, 'Create Contract');
                    contracts.push(contract);
                }
            }
        }
        const created = moment_1.default();
        const log = `Company ${ companyName } Created on ${ created.toString() }

${ noOffices } Offices
${ noUsers } Users
${ noMeasureItems } Measure Sheet Items
${ noEstimates } Estimates
${ noCreditApps } Credit Applications
${ noContracts } Contracts

Company Administrator:
usr: ${ username.padEnd(18, ' ') }pwd: ${ password }

Users:
${ userSeeds.map(({userName, password}) => `usr: ${ userName.padEnd(18, ' ') }pwd: ${ password }\n`).reduce((acc, val) => acc + val, '') }
`;
        const logName = `CreateCompany-${ created.format('YYYY-MM-DD_HH.mm.ss') }`;
        const logPath = path_1.default.join(process.cwd(), logName);
        yield new Promise((resolve, reject) => {
            graceful_fs_1.default.writeFile(logPath, log, { encoding: 'utf-8' }, err => {
                if (err) {
                    reject(err);
                } else {
                    resolve();
                }
            });
        });
        consoleLog('Company fully mocked!', 'success');
        consoleLog(`-Company Admin-`, 'success');
        consoleLog(`Username: ${ username }; Password: ${ password }`);
    } catch (e) {
        console.error(e);
        consoleLog(e, 'danger');
    }
});
exports.default = generateRandCompany;    //# sourceMappingURL=generateRandCompany.js.map
