import { Arg, getValuesFromArgs } from '@/commandLine/args';
import { addConnection } from '@/commandLine/addConnection';
import { useConnection } from '@/commandLine/useConnection';
import { createRandomCompany } from '@/commandLine/createRandomCompany';
import setupDb from '@/database';

const [, , ...args] = [...process.argv];

const argValues = getValuesFromArgs(args);

const main = async (args: Map<Arg, string | number | null>): Promise<void> => {
  const db = await setupDb();

  if (args.size > 0) {
    // Pass args to relavent functions
    const runProcess = async () => {
      if (args.has(Arg.addConnection)) await addConnection(args, db);
      if (args.has(Arg.useConnection)) await useConnection(args, db);
      if (args.has(Arg.createRandCompany)) await createRandomCompany(args, db);
    };
    await runProcess();
  }

  await db.destroy();
  process.exit();
};

main(argValues);
