import { v4 as uuid } from 'uuid';
import { Arg } from './args';
import {
  ParseConfigDocType,
  ParseConfigDocument,
} from '@/data/types/parseConfig';
import { LeapGeneratorDatabase } from '@/data/database';

export const addConnection = async (
  args: Map<Arg, string | null | number>,
  db: LeapGeneratorDatabase
): Promise<ParseConfigDocument> => {
  // Validate args
  const required = [Arg.name, Arg.appId, Arg.url, Arg.masterKey];
  required.forEach((arg) => {
    if (
      !args.has(arg) ||
      args.get(arg) === undefined ||
      args.get(arg) === null ||
      args.get(arg)!.toString().length < 1
    ) {
      throw new Error(`${arg} is required for --addConnection!`);
    }
  });

  const [appId, serverName, serverUrl, jsKey, masterKey] = [
    args.get(Arg.appId)!.toString(),
    args.get(Arg.name)!.toString(),
    args.get(Arg.url)!.toString(),
    args.get(Arg.jsKey)?.toString(),
    args.get(Arg.masterKey)!.toString(),
  ];

  const parseConfig: ParseConfigDocType = {
    id: uuid(),
    active: true,
    appId,
    serverName,
    serverUrl,
    jsKey,
    masterKey,
  };

  const config = await db.parseconfigs.upsert(parseConfig);

  const connected = config.connect();
  console.log(
    '\x1b[32m%s\x1b[0m',
    `Connection ${serverName} added and set as active connection, ${
      connected
        ? 'connected to leap-one server!'
        : `but couldn't connect to leap-one server at ${serverUrl}`
    }`
  );
  return config;
};
