import { Arg } from './args';
import { LeapGeneratorDatabase } from '@/data/database';
import { ParseConfigDocument } from '@/data/types/parseConfig';

export const useConnection = async (
  args: Map<Arg, string | null | number>,
  db: LeapGeneratorDatabase
): Promise<void> => {
  // Validate args
  const required = [Arg.name];
  required.forEach((arg) => {
    if (!args.has(arg)) {
      console.error(new Error(`${arg} is required for --useConnection!`));
    }
  });

  // connect to DB from render process

  const name = args.get(Arg.name);

  const parseConfig: ParseConfigDocument | null = await db.parseconfigs
    .findOne()
    .where('serverName')
    .equals(name)
    .exec();

  if (parseConfig === null) {
    console.error(
      new Error(`No connection config exists with a name of ${name}`)
    );
  } else {
    const connected = await parseConfig.connect();
    const { serverName, serverUrl } = parseConfig;

    console.log(
      '\x1b[32m%s\x1b[0m',
      `Connection ${serverName} added and set as active connection, ${
        connected
          ? 'connected to leap-one server!'
          : `but couldn't connect to leap-one server at ${serverUrl}`
      }`
    );
  }
};
