import { RxJsonSchema } from 'rxdb';
import Address from '../../parse/models/address';
import Company from '../../parse/models/company';
import {
  AddressSeedCollection,
  AddressSeedCollectionMethods,
  AddressSeedDocType,
  AddressSeedDocument,
  AddressSeedMethods,
} from '../types/addressSeed';

export const addressSeedSchema: RxJsonSchema<AddressSeedDocType> = {
  title: 'Parse Config Schema',
  description: 'Connection information for the Parse/LeapOne Server',
  version: 0,
  keyCompression: true,
  type: 'object',
  properties: {
    id: {
      type: 'string',
      primary: true,
    },
    theState: { type: 'string' },
    street: { type: 'string' },
    zipCode: { type: 'string' },
    city: { type: 'string' },
  },
};

export const addressSeedMethods: AddressSeedMethods = {
  async createAddress(
    this: AddressSeedDocument,
    company: Company
  ): Promise<Address> {
    return Address.create({ ...this, company });
  },
};

export const addressSeedCollectionMethods: AddressSeedCollectionMethods = {
  async countAllDocuments(this: AddressSeedCollection) {
    const allDocs = await this.find().exec();
    return allDocs.length;
  },
  async getRandom(this: AddressSeedCollection) {
    const addresss = this.find();
    const count = (await addresss.exec()).length;
    const randId = Math.floor(Math.random() * count + 1);
    const query = this.findOne({
      selector: { id: { $gt: 0 } },
      skip: randId - 1,
    });

    const addressSeed = await query.exec();

    if (addressSeed) {
      return addressSeed;
    } else {
      throw new Error('Could not get Address Seed');
    }
  },
};
