import { RxJsonSchema } from 'rxdb';
import Contact from '../../parse/models/contact';
import Company from '../../parse/models/company';
import {
  ContactSeedCollection,
  ContactSeedCollectionMethods,
  ContactSeedDocType,
  ContactSeedDocument,
  ContactSeedMethods,
} from '../types/contactSeed';

export const contactSeedSchema: RxJsonSchema<ContactSeedDocType> = {
  title: 'Parse Config Schema',
  description: 'Connection information for the Parse/LeapOne Server',
  version: 0,
  keyCompression: true,
  type: 'object',
  properties: {
    id: {
      type: 'string',
      primary: true,
    },
    contact: { type: 'string' },
    type: { type: 'number' },
  },
};

export const contactSeedMethods: ContactSeedMethods = {
  async createContact(
    this: ContactSeedDocument,
    company: Company,
    token: string
  ): Promise<Contact> {
    return Contact.create({ ...this, company }, token);
  },
};

export const contactSeedCollectionMethods: ContactSeedCollectionMethods = {
  async countAllDocuments(this: ContactSeedCollection) {
    const allDocs = await this.find().exec();
    return allDocs.length;
  },
  async getRandom(this: ContactSeedCollection, type: 1 | 2) {
    const contacts = this.find({ selector: { type } });
    const count = (await contacts.exec()).length;
    const randId = Math.floor(Math.random() * count + 1);
    const query = this.findOne({
      selector: { id: { $gt: 0 } },
      skip: randId - 1,
    });

    const contactSeed = await query.exec();

    if (contactSeed) {
      return contactSeed;
    } else {
      throw new Error('Could not get Contact Seed');
    }
  },
};
