/* eslint-disable max-lines */
import { RxJsonSchema, JsonSchema } from 'rxdb';
import Contract, {
  IMockContractObject,
} from '../../parse/models/contractObject';
import Company from '../../parse/models/company';
import Office from '../../parse/models/office';
import User from '../../parse/models/user';
import {
  ContractSeedCollection,
  ContractSeedCollectionMethods,
  ContractSeedDocType,
  ContractSeedDocument,
  ContractSeedMethods,
} from '../types/contractSeed';

const HeaderCellItem: JsonSchema = {
  type: 'object',
  properties: {
    alignment: { type: 'number' },
    cellType: { type: 'string' },
    emptySpaceHeight: { type: 'number' },
    fontBold: { type: 'boolean' },
    fontColor: { type: 'string' },
    fontName: { type: 'string' },
    fontSize: { type: 'number' },
    fontUnderline: { type: 'boolean' },
    image: { type: ['array', 'object'] },
    logoHeight: { type: 'number' },
    objectId: { type: 'string' },
    value: { type: 'string' },
  },
  required: [
    'alignment',
    'cellType',
    'emptySpaceHeight',
    'fontBold',
    'fontSize',
    'logoHeight',
    'value',
  ],
};

const nullableString = { type: ['string', 'null'] };
const numberLike = { type: ['number', 'string'] };

const PurpleCellItem: JsonSchema = {
  type: 'object',
  properties: {
    allowReportPhotos: { type: 'boolean' },
    appNote: { type: 'string' },
    appOnly: { type: 'boolean' },
    appTitle: { type: 'string' },
    cellId: nullableString,
    cellType: { type: 'string' },
    clearValueIfZero: { type: 'boolean' },
    contractTitle: { type: 'string' },
    defaultImageId: { type: 'string' },
    detailItems: {
      type: 'array',
      items: {
        type: 'object',
        properties: {
          allowReportPhotos: { type: 'boolean' },
          appNote: { type: 'string' },
          appOnly: { type: 'boolean' },
          appTitle: { type: 'string' },
          cellId: nullableString,
          cellType: nullableString,
          clearValueIfZero: { type: 'boolean' },
          contractTitle: { type: 'string' },
          defaultImageId: { type: 'string' },
          detailItems: { type: 'array' },
          disableImageLink: { type: 'boolean' },
          drawIfEmpty: { type: 'boolean' },
          dynamicInputType: {
            type: 'object',
            properties: {
              cellId: nullableString,
              objects: { type: 'array', items: { type: 'object' } },
            },
          },
          emptySpaceHeight: { type: 'number' },
          emptyValue: { type: 'string' },
          formula: { type: 'string' },
          formulaWhole: { type: 'string' },
          fractionDigits: { type: 'string' },
          hidden: { type: 'boolean' },
          imageHeight: { type: 'number' },
          images: { type: 'array' },
          imagesSource: { type: 'string' },
          initialsNote: { type: 'string' },
          initialsRequired: { type: 'boolean' },
          inputDisabled: { type: 'boolean' },
          inputType: { type: 'string' },
          isTotalSaleAmount: { type: 'boolean' },
          linkedMeasureSheetItem: { type: 'string' }, // ID of linked MS Ite,
          linkedMeasureSheetItemConfig: {
            type: 'object',
            properties: {
              quantity: { type: 'boolean' },
              unitTotal: { type: 'boolean' },
              title: { type: 'boolean' },
              subtitle: { type: 'boolean' },
              measurementType: { type: 'boolean' },
              total: { type: 'boolean' },
            },
          },
          measueSheetItemTotalIds: { type: 'array', items: { type: 'string' } },
          measureSheetItemQuantityIds: { type: 'array' },
          multiSelectorSeparator: { type: 'string' },
          objectId: { type: 'string' },
          pickerValues: { type: 'array', items: { type: 'string' } },
          required: { type: 'boolean' },
          signatures: { type: 'array' },
          switchValueOff: { type: 'string' },
          switchValueOn: { type: 'string' },
          titleFontBold: { type: 'boolean' },
          titleFontColor: { type: 'string' },
          titleFontName: { type: 'string' },
          titleFontSize: { type: 'number' },
          titleFontUnderline: { type: 'boolean' },
          titleLinked: { type: 'boolean' },
          value: { type: 'string' },
          valueFontBold: { type: 'boolean' },
          valueFontColor: { type: 'string' },
          valueFontName: { type: 'string' },
          valueFontSize: { type: 'number' },
          valueFontUnderline: { type: 'boolean' },
          websiteTitle: { type: 'string' },
        },
      },
    },
    disableImageLink: { type: 'boolean' },
    drawIfEmpty: { type: 'boolean' },
    dynamicInputType: {
      type: 'object',
      properties: {
        cellId: nullableString,
        objects: {
          type: 'array',
          items: {
            type: 'object',
          },
        },
      },
    },
    emptySpaceHeight: { type: 'number' },
    emptyValue: { type: 'string' },
    formula: { type: 'string' },
    formulaWhole: { type: 'string' },
    fractionDigits: { type: 'string' },
    header: {
      type: 'object',
      properties: {
        websiteTitle: { type: 'string' },
        appTitle: { type: 'string' },
        title: { type: 'string' },
        titleFontName: { type: 'string' },
        titleFontSize: { type: 'number' },
        titleFontBold: { type: 'boolean' },
        titleFontColor: { type: 'string' },
        titleFontUnderline: { type: 'boolean' },
        border: { type: ['number', 'string'] },
        cellItems: {
          type: 'array',
          items: {
            type: 'array',
            items: {
              type: 'object',
              properties: {
                alignment: { type: 'number' },
                cellType: { type: 'string' },
                emptySpaceHeight: { type: 'number' },
                fontBold: { type: 'boolean' },
                fontColor: { type: 'string' },
                fontName: { type: 'string' },
                fontSize: { type: 'number' },
                fontUnderline: { type: 'boolean' },
                image: { type: 'array' },
                logoHeight: { type: 'number' },
                objectId: { type: 'string' },
                value: { type: 'string' },
              },
            },
          },
        },
        objectId: { type: 'string' },
      },
    },
    hidden: { type: 'boolean' },
    imageHeight: { type: 'number' },
    images: { type: 'array' },
    imagesSource: { type: 'string' },
    initialsNote: { type: 'string' },
    initialsRequired: { type: 'boolean' },
    inputDisabled: { type: 'boolean' },
    inputType: { type: 'string' },
    isTotalSaleAmount: { type: 'boolean' },
    linkedMeasureSheetItem: { type: 'string' },
    linkedMeasureSheetItemConfig: {
      type: 'object',
      properties: {
        quantity: { type: 'boolean' },
        unitTotal: { type: 'boolean' },
        title: { type: 'boolean' },
        subtitle: { type: 'boolean' },
        measurementType: { type: 'boolean' },
        total: { type: 'boolean' },
      },
    },
    measueSheetItemTotalIds: { type: 'array', items: { type: 'string' } },
    measureSheetItemId: { type: 'string' },
    measureSheetItemQuantityIds: { type: 'array', items: { type: 'string' } },
    measureSheetItemTotalIds: { type: 'array', items: { type: 'string' } },
    multiSelectorSeparator: { type: 'string' },
    objectId: { type: 'string' },
    pickerValues: { type: 'array', items: { type: 'string' } },
    required: { type: 'boolean' },
    signatures: {
      type: 'array',
      properties: {
        objectId: { type: 'string' },
        appNote: { type: 'string' },
        contractNote: { type: 'string' },
        contractNoteFontSize: { type: 'number' },
        contractNoteBold: { type: 'boolean' },
        contractNoteUnderline: { type: 'boolean' },
        contractNoteFontName: { type: 'string' },
        contractNoteFontColor: { type: 'string' },
        footerNote: { type: 'string' },
        underline: { type: 'boolean' },
        column: { type: 'number' },
        additionalLines: {
          type: 'array',
          properties: {
            objectId: { type: 'string' },
            underline: { type: 'boolean' },
            value: { type: 'string' },
            note: { type: 'string' },
            valueFontSize: { type: 'number' },
            valueFontBold: { type: 'boolean' },
            noteFontSize: { type: 'number' },
            noteFontBold: { type: 'boolean' },
            valueFontUnderline: { type: 'boolean' },
            valueFontName: { type: 'string' },
            valueFontColor: { type: 'string' },
            noteFontUnderline: { type: 'boolean' },
            noteFontName: { type: 'string' },
            noteFontColor: { type: 'string' },
            websiteTitle: { type: 'string' },
          },
          required: [
            'underline',
            'value',
            'note',
            'valueFontSize',
            'noteFontBold',
          ],
        },
        websiteTitle: { type: 'string' },
      },
      required: [
        'appNote',
        'contractNote',
        'contractNoteFontSize',
        'contractNoteBold',
        'footerNote',
        'underline',
        'column',
        'additionalLines',
      ],
    },
    switchValueOff: { type: 'string' },
    switchValueOn: { type: 'string' },
    titleFontBold: { type: 'boolean' },
    titleFontColor: { type: 'string' },
    titleFontName: { type: 'string' },
    titleFontSize: { type: 'number' },
    titleFontUnderline: { type: 'boolean' },
    titleLinked: { type: 'boolean' },
    value: { type: 'string' },
    valueFontBold: { type: 'boolean' },
    valueFontColor: { type: 'string' },
    valueFontName: { type: 'string' },
    valueFontSize: { type: 'number' },
    valueFontUnderline: { type: 'boolean' },
    websiteTitle: { type: 'string' },
  },
  required: [
    'appOnly',
    'cellType',
    'drawIfEmpty',
    'imageHeight',
    'initialsRequired',
    'inputType',
    'pickerValues',
    'required',
    'switchValueOff',
    'switchValueOn',
    'titleFontBold',
    'titleFontSize',
  ],
};

export const contractSeedSchema: RxJsonSchema<ContractSeedDocType> = {
  title: 'Parse Config Schema',
  description: 'Connection information for the Parse/LeapOne Server',
  version: 0,
  keyCompression: true,
  type: 'object',
  properties: {
    id: {
      type: 'string',
      primary: true,
    },
    author: { type: 'string' },
    canAddMultiplePages: { type: 'boolean' },
    category: { type: 'string' },
    contractData: {
      type: 'array',
      items: {
        type: 'object',
        properties: {
          objectId: { type: 'string' },
          data: {
            type: 'array',
            items: {
              type: 'object',
              properties: {
                additionalLines: {
                  type: 'array',
                  items: {
                    type: 'object',
                    properties: {
                      objectId: { type: 'string' },
                      underline: { type: 'boolean' },
                      value: { type: 'string' },
                      note: { type: 'string' },
                      valueFontSize: { type: 'number' },
                      valueFontBold: { type: 'boolean' },
                      noteFontSize: { type: 'number' },
                      noteFontBold: { type: 'boolean' },
                      valueFontUnderline: { type: 'boolean' },
                      valueFontName: { type: 'string' },
                      valueFontColor: { type: 'string' },
                      noteFontUnderline: { type: 'boolean' },
                      noteFontName: { type: 'string' },
                      noteFontColor: { type: 'string' },
                      websiteTitle: { type: 'string' },
                    },
                  },
                },
                appNote: { type: 'string' },
                appTitle: { type: 'string' },
                border: numberLike,
                canAddMultiple: { type: 'boolean' },
                cellItems: {
                  type: 'array',
                  items: {
                    type: 'array',
                    items: {
                      type: 'object',
                      properties: {
                        ...HeaderCellItem.properties,
                        ...PurpleCellItem.properties,
                      },
                    },
                  },
                },
                column: { type: 'number' },
                contractNote: { type: 'string' },
                contractNoteBold: { type: 'boolean' },
                contractNoteFontColor: { type: 'string' },
                contractNoteFontName: { type: 'string' },
                contractNoteFontSize: { type: 'number' },
                contractNoteUnderline: { type: 'boolean' },
                contractTitle: { type: 'string' },
                drawBorder: { type: 'boolean' },
                fontBold: { type: 'boolean' },
                fontColor: { type: 'string' },
                fontName: { type: 'string' },
                fontSize: { type: 'number' },
                fontUnderline: { type: 'boolean' },
                footerNote: { type: 'string' },
                linkedMeasureSheetItemIds: {
                  type: 'array',
                  items: { type: 'string' },
                },
                newPage: { type: 'boolean' },
                objectId: { type: 'string' },
                shading: { type: 'number' },
                title: { type: 'string' },
                titleFontBold: { type: 'boolean' },
                titleFontColor: { type: 'string' },
                titleFontName: { type: 'string' },
                titleFontSize: { type: 'number' },
                titleFontUnderline: { type: 'boolean' },
                underline: { type: 'boolean' },
                userInputRequired: { type: 'boolean' },
                websiteTitle: { type: 'string' },
              },
            },
          },
          groupType: { type: 'string' },
        },
      },
    },
    displayName: { type: 'string' },
    excludedStates: { type: 'array', items: { type: 'string' } },
    hMargin: { type: 'number' },
    iconBackgroundColor: { type: 'array', items: { type: 'number' } },
    isCorporateTemplate: { type: 'boolean' },
    isTemplate: { type: 'boolean' },
    order: { type: 'number' },
    pageId: { type: 'string' },
    pageSize: { type: 'string' },
    photosPerPage: { type: 'number' },
    type: { type: 'string' },
    updatedAt: { type: 'string' },
    useWatermark: { type: 'boolean' },
    watermarkAlpha: { type: 'number' },
    watermarkWidthPercent: { type: 'number' },
    wMargin: { type: 'number' },
  },
  required: [
    'author',
    'canAddMultiplePages',
    'category',
    'contractData',
    'displayName',
    'excludedStates',
    'hMargin',
    'iconBackgroundColor',
    'isCorporateTemplate',
    'isTemplate',
    'order',
    'pageId',
    'pageSize',
    'photosPerPage',
    'type',
    'updatedAt',
    'wMargin',
  ],
};

export const contractSeedMethods: ContractSeedMethods = {
  async createContract(
    this: ContractSeedDocument,
    company: Company,
    file: Parse.File,
    iconImageThumb: Parse.File,
    images: Parse.File[],
    includedOffices: Office[],
    lastModifiedBy: User,
    token: string,
    iconImage?: Parse.File,
    pdf?: Parse.File,
    pdfThumbnail?: Parse.File,
    preview?: Parse.File,
    watermark?: Parse.File
  ): Promise<Contract> {
    const {
      author,
      canAddMultiplePages,
      category,
      contractData,
      displayName,
      excludedStates,
      hMargin,
      iconBackgroundColor,
      isCorporateTemplate,
      isTemplate,
      order,
      pageId,
      pageSize,
      photosPerPage,
      type,
      updatedAt,
      useWatermark,
      watermarkAlpha,
      watermarkWidthPercent,
      wMargin,
    } = this;
    const mockContract: IMockContractObject = {
      author,
      canAddMultiplePages,
      category,
      company,
      contractData,
      displayName,
      excludedStates,
      file,
      hMargin,
      iconBackgroundColor,
      iconImage,
      iconImageThumb,
      images,
      includedOffices,
      isCorporateTemplate,
      isTemplate,
      lastModifiedBy,
      order,
      pageId,
      pageSize,
      pdf,
      pdfThumbnail,
      photosPerPage,
      preview,
      type,
      updatedAt,
      useWatermark,
      watermark,
      watermarkAlpha,
      watermarkWidthPercent,
      wMargin,
    };
    return Contract.create(mockContract, token);
  },
};

export const contractSeedCollectionMethods: ContractSeedCollectionMethods = {
  async countAllDocuments(this: ContractSeedCollection) {
    const allDocs = await this.find().exec();
    return allDocs.length;
  },
  async getRandom(this: ContractSeedCollection) {
    const contracts = this.find();
    const count = (await contracts.exec()).length;
    const randId = Math.floor(Math.random() * count + 1);
    const query = this.findOne({
      selector: { id: { $gt: 0 } },
      skip: randId - 1,
    });

    const contractSeed = await query.exec();

    if (contractSeed) {
      return contractSeed;
    } else {
      throw new Error('Could not get Contract Seeed');
    }
  },
};
