/* eslint-disable camelcase */
import { RxJsonSchema } from 'rxdb';
import SSCreditApplication, {
  IMockCreditApplication,
} from '../../parse/models/creditApplication';
import Company from '../../parse/models/company';
import User from '../../parse/models/user';
import Customer from '../../parse/models/customer';
// eslint-disable-next-line max-len
import PartnerCreditApplication from '../../parse/models/partnerCreditApplication';
import {
  CreditAppSeedCollection,
  CreditAppSeedCollectionMethods,
  CreditAppSeedDocType,
  CreditAppSeedDocument,
  CreditAppSeedMethods,
} from '../types/creditApplicationSeed';

export const creditAppSeedSchema: RxJsonSchema<CreditAppSeedDocType> = {
  title: 'Parse Config Schema',
  description: 'Connection information for the Parse/LeapOne Server',
  version: 0,
  keyCompression: true,
  type: 'object',
  properties: {
    id: {
      type: 'string',
      primary: true,
    },
    appId: { type: 'string' },
    date: { type: 'string' },
    decision: {
      type: 'object',
      properties: {
        Decision: { type: 'string' },
        Default_Payment: { type: 'string' },
        Down_Payment: { type: 'string' },
        EPNI_Payment: { type: 'string' },
        Finance_Amount: { type: 'string' },
        Finance_Type: { type: 'string' },
        Rate: { type: 'string' },
        status: { type: 'string' },
        Term: { type: 'string' },
        Total_Amount: { type: 'string' },
      },
    },
    misc: { type: 'object' },
    request: {
      type: 'object',
      properties: {
        amount: { type: 'number' },
        appid: { type: 'number' },
        decision: { type: 'string' },
        error: { type: 'number' },
        payment: { type: 'number' },
        PrgmType: { type: 'string' },
        rate: { type: 'number' },
        refTaskNo: { type: 'number' },
        term: { type: 'number' },
      },
    },
    requestedAmount: { type: 'number' },
    source: { type: 'string' },
  },
};

export const creditAppSeedMethods: CreditAppSeedMethods = {
  async createCreditApp(
    this: CreditAppSeedDocument,
    company: Company,
    createdBy: User,
    customer: Customer,
    token: string,
    partnerApp?: PartnerCreditApplication,
    sourceLogo?: Parse.File
  ): Promise<SSCreditApplication> {
    const {
      appId,
      date,
      decision,
      misc,
      request,
      requestedAmount,
      source,
    } = this;
    const options: IMockCreditApplication = {
      appId,
      date: new Date(date),
      decision,
      misc,
      request,
      requestedAmount,
      source,
      company,
      createdBy,
      customer,
      partnerApp,
      sourceLogo,
    };
    return SSCreditApplication.create(options, token);
  },
};

export const creditAppSeedCollectionMethods: CreditAppSeedCollectionMethods = {
  async countAllDocuments(this: CreditAppSeedCollection) {
    const allDocs = await this.find().exec();
    return allDocs.length;
  },
  async getRandom(this: CreditAppSeedCollection) {
    const creditApps = this.find();
    const count = (await creditApps.exec()).length;
    const randId = Math.floor(Math.random() * count + 1);
    const query = this.findOne({
      selector: { id: { $gt: 0 } },
      skip: randId - 1,
    });

    const creditAppSeed = await query.exec();

    if (creditAppSeed) {
      return creditAppSeed;
    } else {
      throw new Error('Could not get Credit App Seed');
    }
  },
};
