import { RxJsonSchema } from 'rxdb';
import Customer from '../../parse/models/customer';
import SSContact from '../../parse/models/contact';
import SSAddress from '../../parse/models/address';
import SSEstimate from '../../parse/models/estimate';
import Company from '../../parse/models/company';
import User from '../../parse/models/user';
import {
  CustomerSeedCollection,
  CustomerSeedCollectionMethods,
  CustomerSeedDocType,
  CustomerSeedDocument,
  CustomerSeedMethods,
} from '../types/customerSeed';

export const customerSeedSchema: RxJsonSchema<CustomerSeedDocType> = {
  title: 'Parse Config Schema',
  description: 'Connection information for the Parse/LeapOne Server',
  version: 0,
  keyCompression: true,
  type: 'object',
  properties: {
    id: {
      type: 'string',
      primary: true,
    },
    firstName: { type: 'string' },
    lastName: { type: 'string' },
  },
};

export const customerSeedMethods: CustomerSeedMethods = {
  async createCustomer(
    this: CustomerSeedDocument,
    contactPhone: SSContact,
    contactEmail: SSContact,
    address: SSAddress,
    estimate: SSEstimate,
    company: Company,
    creator: User,
    token: string
  ): Promise<Customer> {
    return Customer.create(
      this,
      contactPhone,
      contactEmail,
      address,
      estimate,
      company,
      creator,
      token
    );
  },
};

export const customerSeedCollectionMethods: CustomerSeedCollectionMethods = {
  async countAllDocuments(this: CustomerSeedCollection) {
    const allDocs = await this.find().exec();
    return allDocs.length;
  },
  async getRandom(this: CustomerSeedCollection) {
    const customers = this.find();
    const count = (await customers.exec()).length;
    const randId = Math.floor(Math.random() * count + 1);
    const query = this.findOne({
      selector: { id: { $gt: 0 } },
      skip: randId - 1,
    });

    const customerSeed = await query.exec();

    if (customerSeed) {
      return customerSeed;
    } else {
      throw new Error('Could not get Customer Seed');
    }
  },
};
