import { RxJsonSchema } from 'rxdb';
import Parse from 'parse/node';
import Office from '../../parse/models/office';
import Company from '../../parse/models/company';
import {
  OfficeSeedCollection,
  OfficeSeedCollectionMethods,
  OfficeSeedDocType,
  OfficeSeedDocument,
  OfficeSeedMethods,
} from '../types/officeSeed';

export const officeSeedSchema: RxJsonSchema<OfficeSeedDocType> = {
  title: 'Parse Config Schema',
  description: 'Connection information for the Parse/LeapOne Server',
  version: 0,
  keyCompression: true,
  type: 'object',
  properties: {
    id: {
      type: 'string',
      primary: true,
    },
    name: { type: 'string' },
  },
  required: [],
};

export const officeSeedMethods: OfficeSeedMethods = {
  async checkExists(this: OfficeSeedDocument): Promise<boolean> {
    const { name } = this;
    const query = new Parse.Query(Office);
    query.equalTo('name', name);
    const result = await query.first();
    return !!result;
  },
  async createOffice(
    this: OfficeSeedDocument,
    company: Company,
    token: string
  ): Promise<Office> {
    const { name } = this;
    return Office.create({ name }, company, token);
  },
};

export const officeSeedCollectionMethods: OfficeSeedCollectionMethods = {
  async countAllDocuments(this: OfficeSeedCollection) {
    const allDocs = await this.find().exec();
    return allDocs.length;
  },
  async getExisting(this: OfficeSeedCollection) {
    const parseQuery = new Parse.Query(Company);
    parseQuery.limit(10000);
    const results = await parseQuery.find();

    const nameStatement = results.map((office) => ({
      name: { $eq: office.get('name') },
    }));

    const query = this.find({
      selector: { $or: nameStatement },
    });

    return query.exec();
  },
  async getRandom(this: OfficeSeedCollection) {
    const parseQuery = new Parse.Query(Company);
    parseQuery.limit(10000);
    const results = await parseQuery.find({ useMasterKey: true });

    const nameStatement = results.map((office) => ({
      name: { $ne: office.get('name') },
    }));

    const uniqueOffices = this.find({
      selector: { $and: nameStatement },
    });
    const count = (await uniqueOffices.exec()).length;
    const randId = Math.floor(Math.random() * count + 1);
    const query = this.findOne({
      selector: { $and: nameStatement },
      skip: randId - 1,
    });

    const officeSeed = await query.exec();

    if (officeSeed) {
      return officeSeed;
    } else {
      throw new Error('Could not get Office Seed');
    }
  },
};
