import { LeapGeneratorDatabase } from '../database';
import { IMockAddress } from '../types/addressSeed';
import { CollectionNames } from '../types/collections';
import { seedCollection } from './seedCollection';

// Type gaurd to make sure file parsed is type safe
const isAddressSeedData = (
  seedData: IMockAddress[] | unknown
): seedData is IMockAddress[] => {
  return (
    Array.isArray(seedData) &&
    (seedData as IMockAddress[])
      .map(
        ({ theState, street, zipCode, city }) =>
          typeof theState === 'string' &&
          typeof street === 'string' &&
          typeof zipCode === 'string' &&
          typeof city === 'string'
      )
      .reduce((previous, current) => {
        if (current) return previous;
        return false;
      }, true)
  );
};

const seedAddressData = async (db: LeapGeneratorDatabase): Promise<void> =>
  seedCollection<IMockAddress>(
    db,
    CollectionNames.AddressSeeds,
    isAddressSeedData
  );

export default seedAddressData;
