import { LeapGeneratorDatabase } from '../database';
import { IMockCompany } from '../../parse/types';
import { seedCollection } from './seedCollection';
import { CollectionNames } from '../types/collections';

// Type gaurd to make sure file parsed is type safe
const isCompanySeedData = (
  seedData: IMockCompany[] | unknown
): seedData is IMockCompany[] => {
  return !!(
    Array.isArray(seedData) &&
    (seedData as IMockCompany[])
      .map(
        (seed) =>
          seed.companyName &&
          seed.email &&
          seed.maxActiveUsers &&
          seed.nameFirst &&
          seed.nameLast &&
          seed.officeName &&
          seed.officeName &&
          seed.password &&
          seed.username
      )
      .reduce((previous, current) => {
        if (current) return previous;
        return false;
      }, true)
  );
};

const seedCompanyData = async (db: LeapGeneratorDatabase): Promise<void> =>
  seedCollection<IMockCompany>(
    db,
    CollectionNames.CompanySeeds,
    isCompanySeedData
  );

export default seedCompanyData;
