import { LeapGeneratorDatabase } from '../database';
import { IMockContractObject } from '../../parse/models/contractObject';
import { seedCollection } from './seedCollection';
import { CollectionNames } from '../types/collections';

const isContractSeedData = (
  seedData: IMockContractObject[] | unknown
): seedData is IMockContractObject[] => {
  return (
    Array.isArray(seedData) &&
    (seedData as IMockContractObject[])
      .map((item) => {
        const {
          author,
          canAddMultiplePages,
          category,
          contractData,
          displayName,
          excludedStates,
          hMargin,
          iconBackgroundColor,
          isCorporateTemplate,
          isTemplate,
          order,
          pageId,
          pageSize,
          photosPerPage,
          type,
          updatedAt,
          wMargin,
        } = item;
        const validFields: [
          (
            | 'author'
            | 'canAddMultiplePages'
            | 'category'
            | 'contractData'
            | 'displayName'
            | 'excludedStates'
            | 'hMargin'
            | 'iconBackgroundColor'
            | 'isCorporateTemplate'
            | 'isTemplate'
            | 'order'
            | 'pageId'
            | 'pageSize'
            | 'photosPerPage'
            | 'type'
            | 'updatedAt'
            | 'wMargin'
          ),
          boolean
        ][] = [
          ['author', typeof author === 'string'],
          ['canAddMultiplePages', typeof canAddMultiplePages === 'boolean'],
          ['category', typeof category === 'string'],
          ['contractData', typeof contractData === 'object'],
          ['displayName', typeof displayName === 'string'],
          [
            'excludedStates',
            !!(
              Array.isArray(excludedStates) &&
              excludedStates.reduce(
                (acc, val) => acc && typeof val === 'string',
                true
              )
            ),
          ],
          ['hMargin', typeof hMargin === 'number'],
          [
            'iconBackgroundColor',
            !!(
              Array.isArray(iconBackgroundColor) &&
              iconBackgroundColor.reduce(
                (acc, val) => acc && typeof val === 'number',
                true
              )
            ),
          ],
          ['isCorporateTemplate', typeof isCorporateTemplate === 'boolean'],
          ['isTemplate', typeof isTemplate === 'boolean'],
          ['order', typeof order === 'number'],
          ['pageId', typeof pageId === 'string'],
          ['pageSize', typeof pageSize === 'string'],
          ['photosPerPage', typeof photosPerPage === 'number'],
          ['type', typeof type === 'string'],
          ['updatedAt', typeof updatedAt === 'string'],
          ['wMargin', typeof wMargin === 'number'],
        ];

        let invalidField: string | null = null;

        validFields.forEach((field) => {
          if (!field[1]) {
            const key = field[0];
            invalidField = `{${key}: ${item[key]}}`;
          }
        });

        if (invalidField) {
          throw new Error(`Invalid field: ${invalidField}`);
        }
        return invalidField === null;
      })
      .reduce((previous, current) => {
        if (current) return previous;
        return false;
      }, true)
  );
};

const seedContractData = async (db: LeapGeneratorDatabase): Promise<void> =>
  seedCollection<IMockContractObject>(
    db,
    CollectionNames.ContractSeeds,
    isContractSeedData
  );

export default seedContractData;
