import { LeapGeneratorDatabase } from '../database';
import { IBaseCreditApplication } from '../../parse/models/creditApplication';
import { seedCollection } from './seedCollection';
import { CollectionNames } from '../types/collections';

const isCreditSeedData = (
  seedData: IBaseCreditApplication[] | unknown
): seedData is IBaseCreditApplication[] => {
  return (
    Array.isArray(seedData) &&
    (seedData as IBaseCreditApplication[])
      .map(
        ({ appId, date, decision, misc, request, requestedAmount, source }) => {
          const valid =
            typeof appId === 'string' &&
            typeof date === 'string' &&
            typeof decision === 'object' &&
            // optional field
            (misc !== undefined ? typeof misc === 'object' : true) &&
            typeof request === 'object' &&
            typeof requestedAmount === 'number' &&
            // optional field
            (source !== undefined ? typeof source === 'string' : true);
          if (!valid) {
            console.warn('Invalid obj!');
            console.log({
              appId,
              date,
              decision,
              misc,
              request,
              requestedAmount,
              source,
            });
          }
          return valid;
        }
      )
      .reduce((previous, current) => {
        if (current) return previous;
        return false;
      }, true)
  );
};

const seedCreditAppData = async (db: LeapGeneratorDatabase): Promise<void> =>
  seedCollection<IBaseCreditApplication>(
    db,
    CollectionNames.CreditAppSeeds,
    isCreditSeedData
  );

export default seedCreditAppData;
