import { LeapGeneratorDatabase } from '../database';
import { IMockCustomer } from '../types/customerSeed';
import { seedCollection } from './seedCollection';
import { CollectionNames } from '../types/collections';

const isCustomerSeedData = (
  seedData: IMockCustomer[] | unknown
): seedData is IMockCustomer[] => {
  return (
    Array.isArray(seedData) &&
    (seedData as IMockCustomer[])
      .map(
        ({ firstName, lastName }) =>
          typeof firstName === 'string' && typeof lastName === 'string'
      )
      .reduce((previous, current) => {
        if (current) return previous;
        return false;
      }, true)
  );
};

const seedCustomerData = async (db: LeapGeneratorDatabase): Promise<void> =>
  seedCollection<IMockCustomer>(
    db,
    CollectionNames.CustomerSeeds,
    isCustomerSeedData
  );

export default seedCustomerData;
