import { LeapGeneratorDatabase } from '../database';
import { SeedFileDocType, DefaultPaths } from '../types/seedFile';
import { CollectionNames } from '../types/collections';

export default async (db: LeapGeneratorDatabase): Promise<void> => {
  const files = new Map<CollectionNames, DefaultPaths>([
    [CollectionNames.AddressSeeds, DefaultPaths.AddressSeeds],
    [CollectionNames.CompanySeeds, DefaultPaths.CompanySeeds],
    [CollectionNames.ContactSeeds, DefaultPaths.ContactSeeds],
    [CollectionNames.ContractSeeds, DefaultPaths.ContractSeeds],
    [CollectionNames.CreditAppSeeds, DefaultPaths.CreditAppSeeds],
    [CollectionNames.CustomerSeeds, DefaultPaths.CustomerSeeds],
    [CollectionNames.EstimateSeeds, DefaultPaths.EstimateSeeds],
    [CollectionNames.OfficeSeeds, DefaultPaths.OfficeSeeds],
    [CollectionNames.PriceGuideSeeds, DefaultPaths.PriceGuideSeeds],
    [CollectionNames.UserSeeds, DefaultPaths.UserSeeds],
  ]);

  const bulkInserts: SeedFileDocType[] = [];
  for (const [collection, fileName] of files) {
    const fileDoc = await db.seedfiles.findOne(collection).exec();
    if (!fileDoc) {
      try {
        bulkInserts.push({
          fileName,
          collectionName: collection,
          fileLastModified: '',
        });
      } catch (e) {
        console.error(e);
      }
    }
  }

  await db.seedfiles.bulkInsert(bulkInserts);
};
