import { LeapGeneratorDatabase } from '../database';
import { IMockUser } from '../../parse/types';
import { seedCollection } from './seedCollection';
import { CollectionNames } from '../types/collections';

const isUserSeedData = (
  seedData: IMockUser[] | unknown
): seedData is IMockUser[] => {
  return !!(
    Array.isArray(seedData) &&
    (seedData as IMockUser[])
      .map(
        (seed) =>
          seed.userName &&
          seed.email &&
          seed.nameFirst &&
          seed.nameLast &&
          seed.phoneNumber &&
          seed.licenseNumber &&
          seed.password
      )
      .reduce((previous, current) => {
        if (current) return previous;
        return false;
      }, true)
  );
};

const seedUserData = async (db: LeapGeneratorDatabase): Promise<void> =>
  seedCollection<IMockUser>(db, CollectionNames.UserSeeds, isUserSeedData);

export default seedUserData;
