import { RxCollection, RxDocument } from 'rxdb';
import Company from '../../parse/models/company';

// Saved server connection doc types
export type CompanySeedDocType = {
  id: string; // will be an integer in string form
  companyName: string;
  maxActiveUsers: number;
  officeName: string;
  username: string;
  password: string;
  nameFirst: string;
  nameLast: string;
  email: string;
};

export type CompanySeedMethods = {
  checkExists: () => Promise<boolean>;
  createCompany: (
    maxActiveUsers: number,
    partnerTag: 'Leap' | 'Prosell'
  ) => Promise<Company>;
  getAccountCredentials: () => { username: string; password: string };
};

export type CompanySeedDocument = RxDocument<
  CompanySeedDocType,
  CompanySeedMethods
>;

export type CompanySeedCollectionMethods = {
  countAllDocuments: () => Promise<number>;
  getExisting: () => Promise<CompanySeedDocument[]>;
  getRandom: () => Promise<CompanySeedDocument>;
};

export type CompanySeedCollection = RxCollection<
  CompanySeedDocType,
  CompanySeedMethods,
  CompanySeedCollectionMethods
>;
