import { RxCollection, RxDocument } from 'rxdb';
import Company from '../../parse/models/company';
import Office from '../../parse/models/office';
import User from '../../parse/models/user';
import ContractObject, {
  IBaseContractObject,
} from '../../parse/models/contractObject';

export type ContractSeedDocType = IBaseContractObject & {
  id: string; // will be an integer in string form
};

export type ContractSeedMethods = {
  createContract: (
    company: Company,
    file: Parse.File,
    iconImageThumb: Parse.File,
    images: Parse.File[],
    includedOffices: Office[],
    lastModifiedBy: User,
    token: string,
    iconImage?: Parse.File,
    pdf?: Parse.File,
    pdfThumbnail?: Parse.File,
    preview?: Parse.File,
    watermark?: Parse.File
  ) => Promise<ContractObject>;
};

export type ContractSeedDocument = RxDocument<
  ContractSeedDocType,
  ContractSeedMethods
>;

export type ContractSeedCollectionMethods = {
  countAllDocuments: () => Promise<number>;
  getRandom: () => Promise<ContractSeedDocument>;
};

export type ContractSeedCollection = RxCollection<
  ContractSeedDocType,
  ContractSeedMethods,
  ContractSeedCollectionMethods
>;
