import { RxCollection, RxDocument } from 'rxdb';
import Customer from '../../parse/models/customer';
import SSContact from '../../parse/models/contact';
import SSAddress from '../../parse/models/address';
import SSEstimate from '../../parse/models/estimate';
import Company from '../../parse/models/company';
import User from '../../parse/models/user';

export interface IMockCustomer {
  firstName: string;
  lastName: string;
}

export type CustomerSeedDocType = IMockCustomer & {
  id: string; // will be an integer in string form
};

export type CustomerSeedMethods = {
  createCustomer: (
    contactPhone: SSContact,
    contactEmail: SSContact,
    address: SSAddress,
    estimate: SSEstimate,
    company: Company,
    creator: User,
    token: string
  ) => Promise<Customer>;
};

export type CustomerSeedDocument = RxDocument<
  CustomerSeedDocType,
  CustomerSeedMethods
>;

export type CustomerSeedCollectionMethods = {
  countAllDocuments: () => Promise<number>;
  getRandom: () => Promise<CustomerSeedDocument>;
};

export type CustomerSeedCollection = RxCollection<
  CustomerSeedDocType,
  CustomerSeedMethods,
  CustomerSeedCollectionMethods
>;
