/* eslint-disable @typescript-eslint/ban-types */
import { RxCollection, RxDocument } from 'rxdb';
import Estimate, {
  ILeadResult,
  IMeasureItem,
  ICustomProductItem,
} from '../../parse/models/estimate';
import Office from '../../parse/models/office';
import Company from '../../parse/models/company';

export type EstimateSeed = {
  activeProductCategories: string[];
  addedMeasureSheetItems: (IMeasureItem | ICustomProductItem)[];
  contractPDF: string;
  creditAppPDF: string;
  downPayment: number;
  financeAmount: number;
  isSale: boolean;
  leadResults: ILeadResult[];
  resultFullString: string;
  resultPDF: string;
  saleAmount: number;
  selectedEmailLinks: {
    [documentType: string]: {
      linkName: string;
      id: string;
      name: string;
      category: string;
      link: string;
    }[];
  };
};

export type EstimateSeedDocType = EstimateSeed & {
  id: string; // will be an integer in string form
};

export type EstimateSeedMethods = {
  createEstimate: (office: Office, company: Company) => Promise<Estimate>;
};

export type EstimateSeedDocument = RxDocument<
  EstimateSeedDocType,
  EstimateSeedMethods
>;

export type EstimateSeedCollectionMethods = {
  countAllDocuments: () => Promise<number>;
  getRandom: () => Promise<EstimateSeedDocument>;
};

export type EstimateSeedCollection = RxCollection<
  EstimateSeedDocType,
  EstimateSeedMethods,
  EstimateSeedCollectionMethods
>;
