import { RxCollection, RxDocument } from 'rxdb';
import Office from '../../parse/models/office';
import Company from '../../parse/models/company';
import MeasureSheetItem from '../../parse/models/measureSheetItem';
import { IMockPriceItem } from '../../parse/types';

// Saved server connection doc types
export type PriceGuideSeedDocType = {
  id: string; // will be an integer in string form
  itemCount: number;
  items: IMockPriceItem[];
  category: string;
  subCategory: string;
  subSubCategory: string;
  subSubcategories: string;
  itemName: string;
  itemNote: string;
  measurementType: string;
  shouldShowSwitch: boolean;
  orderNumber: number;
};

export type PriceGuideSeedMethods = {
  checkExists: () => Promise<boolean>;
  createPriceGuideItem: (
    company: Company,
    offices: Office[],
    token: string
  ) => Promise<MeasureSheetItem>;
};

export type PriceGuideSeedDocument = RxDocument<
  PriceGuideSeedDocType,
  PriceGuideSeedMethods
>;

export type PriceGuideSeedCollectionMethods = {
  countAllDocuments: () => Promise<number>;
  getRandom: (company: Company) => Promise<PriceGuideSeedDocument>;
};

export type PriceGuideSeedCollection = RxCollection<
  PriceGuideSeedDocType,
  PriceGuideSeedMethods,
  PriceGuideSeedCollectionMethods
>;
