import { RxCollection, RxDocument } from 'rxdb';
import { CollectionNames } from './collections';

export enum DefaultPaths {
  AddressSeeds = 'seedAddressData.json',
  CompanySeeds = 'seedCompanyData.json',
  ContactSeeds = 'seedContactData.json',
  ContractSeeds = 'seedContractData.json',
  CreditAppSeeds = 'seedCreditApplicationData.json',
  CustomerSeeds = 'seedCustomerData.json',
  EstimateSeeds = 'seedEstimateData.json',
  OfficeSeeds = 'seedOfficeData.json',
  PriceGuideSeeds = 'seedPriceGuideData.json',
  UserSeeds = 'seedUserData.json',
}

export type SeedFileDocType = {
  collectionName: CollectionNames; // Since it's unique, will use as primary key
  fileLastModified: string; // ISO Date string
  fileName: string;
};

export type SeedFileMethods = {
  readFile: <T>() => Promise<T>; // T is the type you're expecting from the JSON
  updateLastModified: () => Promise<void>;
  wasFileModified: () => Promise<boolean>;
};

export type SeedFileDocument = RxDocument<SeedFileDocType, SeedFileMethods>;

// eslint-disable-next-line @typescript-eslint/ban-types
export type SeedFileCollectionMethods = {
  countAllDocuments: () => Promise<number>;
};

export type SeedFileCollection = RxCollection<
  SeedFileDocType,
  SeedFileMethods,
  SeedFileCollectionMethods
>;
