import { RxCollection, RxDocument } from 'rxdb';
import User from '../../parse/models/user';
import Office from '../../parse/models/office';

// Saved server connection doc types
export type UserSeedDocType = {
  id: string; // will be an integer in string form
  userName: string;
  email: string;
  nameFirst: string;
  nameLast: string;
  phoneNumber: string;
  licenseNumber: number;
  password: string;
};

export type UserSeedMethods = {
  checkExists: () => Promise<boolean>;
  createUser: (office: Office, token: string) => Promise<User>;
  getAccountCredentials: () => { username: string; password: string };
};

export type UserSeedDocument = RxDocument<UserSeedDocType, UserSeedMethods>;

export type UserSeedCollectionMethods = {
  countAllDocuments: () => Promise<number>;
  getExisting: () => Promise<UserSeedDocument[]>;
  getRandom: () => Promise<UserSeedDocument>;
};

export type UserSeedCollection = RxCollection<
  UserSeedDocType,
  UserSeedMethods,
  UserSeedCollectionMethods
>;
