import pouchAdapter from 'pouchdb-adapter-leveldb';
import { addRxPlugin } from 'rxdb';
import leveldown from 'leveldown';
import { initializeDatabase, LeapGeneratorDatabase } from '@/data/database';
import { ConsoleColor } from '@/commandLine/types';

addRxPlugin(pouchAdapter);

export default async (): Promise<LeapGeneratorDatabase> =>
  new Promise((resolve, reject) => {
    let leapDb: LeapGeneratorDatabase;
    const db$ = initializeDatabase(leveldown);
    db$.subscribe(
      ({ message, progress, db }) => {
        console.log(
          ConsoleColor.FgCyan + ConsoleColor.Content + ConsoleColor.Reset,
          `Loading DB: ${progress}% - ${message}`
        );
        if (db) {
          leapDb = db;
        }
      },
      (err: Error) => {
        console.error(err);
        reject(err);
      },
      () => {
        resolve(leapDb);
      }
    );
  });
