import Parse from 'parse/node';
import Office from './models/office';
import Company from './models/company';
import User from './models/user';
import SSAddress from './models/address';
import SSContact from './models/contact';
import SSCustomer from './models/customer';
import SSEstimate from './models/estimate';
import SSMeasureSheetItem from './models/measureSheetItem';
import SSPriceGuideItem from './models/priceGuideItem';

type ParseConfig = {
  appId: string;
  jsKey?: string;
  masterKey: string;
  serverUrl: string;
};

export default ({ appId, jsKey, masterKey, serverUrl }: ParseConfig): void => {
  // Initialize Parse SDK. NOTE: parse server must be running!
  Parse.initialize(appId);
  // Why? because Parse is dumb, and Parse.intialize doesn't always work
  Parse.applicationId = appId;
  Parse.masterKey = masterKey;
  Parse.javaScriptKey = jsKey;
  Parse.serverURL = serverUrl;

  // Register custom classes as parse objects
  ([
    ['Office', Office],
    ['_User', User],
    ['Company', Company],
    ['SSAddress', SSAddress],
    ['SSContact', SSContact],
    ['SSCustomer', SSCustomer],
    ['SSEstimate', SSEstimate],
    ['SSMeasureSheetItem', SSMeasureSheetItem],
    ['SSPriceGuideItem', SSPriceGuideItem],
  ] as const).forEach(([name, clss]) =>
    Parse.Object.registerSubclass(name, clss)
  );

  // Create admin company/user if it doesn't exist
  const createAdminCompany = async () => {
    const query = new Parse.Query(Company);
    query.equalTo('name', 'Admin Company');
    const result = await query.first({ useMasterKey: true });
    if (!result) {
      await Company.create({
        companyName: 'Admin Company',
        maxActiveUsers: 1,
        officeName: 'Admin Office',
        username: 'admin',
        password: '3uBdmFkLMC3F#g*8C',
        nameFirst: 'Dev',
        nameLast: 'Admin',
        email: 'devadmin@leap.com',
        partnerTag: 'Leap',
      });
      console.log('Admin company created');
    }
  };
  createAdminCompany();
};
