/* eslint-disable camelcase */
import Parse from 'parse/node';
import Company from './company';
import Customer from './customer';
import User from './user';
import PartnerCreditApplication from './partnerCreditApplication';

export interface IBaseCreditApplication {
  appId: string;
  date: Date;
  decision: {
    Decision: string;
    Default_Payment: string;
    Down_Payment: string;
    EPNI_Payment: string;
    Finance_Amount: string;
    Finance_Type: string;
    Rate: string;
    status: string;
    Term: string;
    Total_Amount: string;
  };
  misc?: Record<string, unknown>;
  request: {
    amount: number;
    appid: number;
    decision: string;
    error: number;
    payment: number;
    PrgmType: string;
    rate: number;
    refTaskNo: number;
    term: number;
  };
  requestedAmount: number;
  source?: string;
}

export interface IMockCreditApplication extends IBaseCreditApplication {
  company: Company;
  createdBy: User;
  customer: Customer;
  partnerApp?: PartnerCreditApplication;
  sourceLogo?: Parse.File;
}

class SSCreditApplication extends Parse.Object {
  constructor(options?: IMockCreditApplication) {
    super('SSCreditApplication', options);
  }

  static async create(
    mockCreditApp: IMockCreditApplication,
    token: string
  ): Promise<SSCreditApplication> {
    const options = { sessionToken: token };
    const creditApp = new SSCreditApplication(mockCreditApp);
    await creditApp.save(null, options);
    return creditApp;
  }
}

export default SSCreditApplication;
