import Parse from 'parse/node';
import SSPriceGuideItem from './priceGuideItem';
import Company from './company';
import Office from './office';
import { ICreateMeasureSheetItem } from '../types';

export interface IMeasureSheetAttributes {
  accessories: SSPriceGuideItem[];
  accessoriesCount: number;
  accessoriesRelation: SSPriceGuideItem[];
  additionalDetailObjects: [];
  category: string;
  company: Company;
  contractData: Record<string, unknown>;
  defaultQty: number;
  formulaID: string;
  image: File;
  includedOffices: Office[];
  itemCode: string;
  itemName: string;
  itemNote: string;
  items: SSPriceGuideItem[];
  itemsRelation: SSPriceGuideItem[];
  linkedMeasurementSources: [];
  measurementType: string;
  name: string;
  orderNumber_: number;
  placeholders: string[];
  qtyFormula: string;
  shouldShowSwitch: boolean;
  subCategory: string;
  subSubCategories: string;
  tagDefaultValue: string;
  tagInputType: string;
  tagNote: string;
  tagTitle: string;
  additionalDetails: [];
  displayTitle: string;
  itemCount: number;
  orderNumber: number;
  tagPickerOptions: [];
  tagRequired: boolean;
  sourceObjectId: string;
  subCategory2: string;
}

class SSMeasureSheetItem extends Parse.Object {
  // eslint-disable-next-line @typescript-eslint/ban-types
  constructor(options?: {}) {
    super('SSMeasureSheetItem', options);
  }

  attributes!: IMeasureSheetAttributes;

  static async create(
    itemMock: ICreateMeasureSheetItem,
    company: Company,
    offices: Office[],
    token: string
  ): Promise<SSMeasureSheetItem> {
    const options = { sessionToken: token };
    const { items, ...measureSheetData } = itemMock;

    // Create price guide item(s)
    const priceGuideItems = await Promise.all(
      items.map(async (priceGuideData) => {
        const { itemPrices } = priceGuideData;
        // If no total data exists, make it 0
        const total =
          (Array.isArray(itemPrices) &&
            itemPrices.length > 0 &&
            itemPrices[0].total) ||
          0;
        const priceGuideItem = new SSPriceGuideItem({
          ...priceGuideData,
          itemPrices: offices.map(({ id }) => ({ officeId: id, total })),
          company,
        });

        await priceGuideItem.save(null, options);
        return priceGuideItem;
      })
    );

    // Create measure sheet item
    const measureSheetItem: SSMeasureSheetItem = new SSMeasureSheetItem({
      ...measureSheetData,
      items: priceGuideItems,
    });

    await measureSheetItem.save(null, options);

    return measureSheetItem;
  }
}

export default SSMeasureSheetItem;
