import Parse from 'parse/node';
import { ICustomConfig, IMockOffice, Edit } from '../types';
import Company from './company';

interface IOfficeAttributes {
  name: string;
  abbv: string;
  msCompanyId: string;
  order: number;
  copiedOfficeId: string;
  company: Company;
  config: ICustomConfig;
  copySettingsFrom: string;
  isNewCompany: boolean;
  edits: Edit[];
  isCorporateAccount: boolean;
  canSearchAllEstimates: boolean;
  deleteFileWhenInactive: boolean;
}

class Office extends Parse.Object {
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  constructor(options?: unknown) {
    super('Office');
  }

  attributes!: IOfficeAttributes;

  static async create(
    attributes: IMockOffice,
    company: Company,
    token: string
  ): Promise<Office> {
    // Get initial office from company to copy from
    const initialOffice = company.get('offices')[0];
    const copyId = initialOffice.id;

    // Cloud function call, run as first company user
    // Returns a success message (string), so we'll need to manually find the
    // office object upon successful creation
    await Parse.Cloud.run(
      'createNewOffice',
      {
        ...attributes,
        priceGuideCopy: copyId,
        appSettingsCopy: copyId,
        contractsCopy: [copyId],
        proposalsCopy: [copyId],
        packagesCopy: [copyId],
        resourcesCopy: [copyId],
        financeOptionsCopy: [copyId],
      },
      {
        sessionToken: token,
      }
    );

    // Find the office Parse object we created
    const queryNewOffice = new Parse.Query(Office);
    const office = await queryNewOffice.equalTo('name', attributes.name).first({
      useMasterKey: true,
    });

    if (office) {
      return office;
    } else {
      throw new Error('Could not retreive created office!');
    }
  }
}

export default Office;
