import Parse from 'parse/node';
import Office from './office';
import Company from './company';
import { ICreateUser } from '../types';

export interface IUserAttributes {
  updatedAt: Date;
  createdAt: Date;
  username: string;
  email: string;
  emailVerified: boolean;
  authData: Record<string, unknown>;
  allowedOffices: Office[];
  isActive: boolean;
  nameFirst: string;
  searchableTimeCustomer: number;
  nameLastLowerCase: string;
  userSettings: Record<string, unknown>;
  company: Company;
  additionalMinimumAmount: number;
  selectedOffice: Office;
  nameFirstLowerCase: string;
  canChangeSettings: boolean;
  nameLast: string;
  isManager: boolean;
  needsResetPassword: boolean;
  canSubmitCreditApps: boolean;
}

class User extends Parse.User {
  constructor(attributes: IUserAttributes) {
    super(attributes);
  }

  attributes!: IUserAttributes;

  static async create(attributes: ICreateUser, token: string): Promise<User> {
    const user: User = await Parse.Cloud.run(
      'signupUser',
      { ...attributes, licenseNumber: attributes.licenseNumber.toString() },
      {
        sessionToken: token,
      }
    );

    // After sign up, the user is logged in, log out user
    Parse.User.logOut();

    // Add the user to the company's sales rep group
    await user.fetch({ useMasterKey: true });
    const company = user.get('company');
    const companyId = company.id;
    const query = new Parse.Query(Parse.Role);
    const role = await query
      .equalTo('name', `SalesRep_${companyId}`)
      .first({ useMasterKey: true });
    if (role) {
      try {
        role.getUsers().add(user);
        await role.save(null, { useMasterKey: true });
      } catch (e) {
        console.error(e);
      }
    }

    return user;
  }
}

export default User;
