/* eslint-disable @typescript-eslint/no-empty-interface */
import Company from './models/company';
import Office from './models/office';

export type loginPayload = {
  username: string;
  password: string;
  source: 'mobile' | 'website';
};

export type MockDict = {
  company: IMockCompany[];
  office: IMockOffice[];
  user: IMockUser[];
  priceGuide: IMockMeasureSheetItem[];
};

export interface IMockCompany {
  companyName: string;
  maxActiveUsers: number;
  officeName: string;
  username: string;
  password: string;
  nameFirst: string;
  nameLast: string;
  email: string;
}

export type Edit = {
  user: string;
  date: Date;
  changes: string;
};

export interface ICustomConfig {}

export interface ICreateCompany extends IMockCompany {
  partnerTag: 'Leap' | 'Prosell';
}

export interface IDefineCompany extends ICreateCompany {
  type:
    | 'exterior'
    | 'concrete'
    | 'bci'
    | 'rebath'
    | 'prosell'
    | 'leapPro'
    | 'flooring';
  size: 'sm' | 'md' | 'lg';
}

export interface IMockOffice {
  name: string;
}

export interface ICreateOffice extends IMockOffice {
  priceGuideCopy: string;
  appSettingsCopy: string;
  contractsCopy: string[];
  proposalsCopy: string[];
  packagesCopy: string[];
  resourcesCopy: string[];
  financeOptionsCopy: string[];
}

export interface IMockUser {
  userName: string;
  email: string;
  nameFirst: string;
  nameLast: string;
  phoneNumber: string;
  licenseNumber: number;
  password: string;
}

export interface IMockMeasureSheetItem {
  category: string;
  itemCount: number;
  itemName: string;
  itemNote: string;
  items: IMockPriceItem[];
  measurementType: string;
  orderNumber: number;
  shouldShowSwitch: boolean;
  subCategory: string;
  subSubcategories: string;
  subSubCategory: string;
}

export interface IMockPriceItem {
  accessories: IMockPriceItem[];
  accessoriesPricesDict: {
    [objectId: string]: {
      [objectId: string]: number;
    };
  };
  accessoryPrices: IMockPriceItem[];
  additionalDetails: {
    cellType: string;
    defaultValue: string;
    inputType: string;
    note: string;
    objectId: string;
    placeholder: string;
    required: boolean;
    shouldCopy: boolean;
    title: string;
  }[];
  category: string;
  commissionable: boolean;
  disabledParents: string[];
  displayTitle: string;
  identifier: string;
  info: string;
  isAccessory: boolean;
  itemCode: string;
  itemCodes: { [id: string]: string };
  itemPrices: { total: number }[];
  measurementType: string;
  name: string;
  orderNumber: number;
  parArray: number[];
  parentItem: string;
  percentagePrice: boolean;
  placeholders: { placeholder: string; replacement: string; id: string }[];
  pricesDict: { [objectId: string]: number };
  shouldShowSwitch: 0 | 1;
  subCategory: string;
  subCategory2: string;
}

export interface IMockCustomer {}

export interface ICreateUser {
  username: string;
  office: string;
  password: string;
  email: string;
  nameFirst: string;
  nameLast: string;
  phoneNumber: string;
  licenseNumber: number;
  apiCredentials: [];
  allowedOffices: string[] | null;
}

export type LoginResponse = {
  type: 'success' | 'error';
  message: string;
  result: Parse.Session;
};

export interface ICreateMeasureSheetItem {
  company: Company;
  category: string;
  includedOffices: Office[];
  itemName: string;
  itemNote: string;
  items: IMockPriceItem[];
  measurementType: string;
  orderNumber: number;
  shouldShowSwitch: boolean;
  subCategory: string;
  subSubcategories: string;
  subSubCategory: string;
}

export interface ICreatePriceGuideItem {}
